@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsframegraph.h"
+#include "moc_qgsframegraph.cpp"
 #include "qgsdirectionallightsettings.h"
 #include "qgspostprocessingentity.h"
 #include "qgspreviewquad.h"
@@ -21,7 +22,7 @@
 #include "qgsambientocclusionrenderentity.h"
 #include "qgsambientocclusionblurentity.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
 #include <Qt3DRender/QAttribute>
 #include <Qt3DRender/QBuffer>
 #include <Qt3DRender/QGeometry>
@@ -378,7 +379,8 @@ Qt3DRender::QFrameGraphNode *QgsFrameGraph::constructAmbientOcclusionRenderPass(
   mAmbientOcclusionRenderStateSet = new Qt3DRender::QRenderStateSet( mAmbientOcclusionRenderCameraSelector );
 
   Qt3DRender::QDepthTest *depthRenderDepthTest = new Qt3DRender::QDepthTest;
-  depthRenderDepthTest->setDepthFunction( Qt3DRender::QDepthTest::Always );;
+  depthRenderDepthTest->setDepthFunction( Qt3DRender::QDepthTest::Always );
+  ;
   Qt3DRender::QCullFace *depthRenderCullFace = new Qt3DRender::QCullFace;
   depthRenderCullFace->setMode( Qt3DRender::QCullFace::NoCulling );
 
@@ -426,7 +428,8 @@ Qt3DRender::QFrameGraphNode *QgsFrameGraph::constructAmbientOcclusionBlurPass()
   mAmbientOcclusionBlurStateSet = new Qt3DRender::QRenderStateSet( mAmbientOcclusionBlurCameraSelector );
 
   Qt3DRender::QDepthTest *depthRenderDepthTest = new Qt3DRender::QDepthTest;
-  depthRenderDepthTest->setDepthFunction( Qt3DRender::QDepthTest::Always );;
+  depthRenderDepthTest->setDepthFunction( Qt3DRender::QDepthTest::Always );
+  ;
   Qt3DRender::QCullFace *depthRenderCullFace = new Qt3DRender::QCullFace;
   depthRenderCullFace->setMode( Qt3DRender::QCullFace::NoCulling );
 
@@ -490,7 +493,6 @@ Qt3DRender::QFrameGraphNode *QgsFrameGraph::constructRubberBandsPass()
 }
 
 
-
 Qt3DRender::QFrameGraphNode *QgsFrameGraph::constructDepthRenderPass()
 {
   // depth buffer render to copy pass
@@ -502,7 +504,8 @@ Qt3DRender::QFrameGraphNode *QgsFrameGraph::constructDepthRenderPass()
   mDepthRenderStateSet = new Qt3DRender::QRenderStateSet( mDepthRenderCameraSelector );
 
   Qt3DRender::QDepthTest *depthRenderDepthTest = new Qt3DRender::QDepthTest;
-  depthRenderDepthTest->setDepthFunction( Qt3DRender::QDepthTest::Always );;
+  depthRenderDepthTest->setDepthFunction( Qt3DRender::QDepthTest::Always );
+  ;
   Qt3DRender::QCullFace *depthRenderCullFace = new Qt3DRender::QCullFace;
   depthRenderCullFace->setMode( Qt3DRender::QCullFace::NoCulling );
 
@@ -562,7 +565,7 @@ Qt3DCore::QEntity *QgsFrameGraph::constructDepthRenderQuad()
 
   Qt3DQGeometry *geom = new Qt3DQGeometry;
   Qt3DQAttribute *positionAttribute = new Qt3DQAttribute;
-  const QVector<float> vert = { -1.0f, -1.0f, 1.0f, /**/ 1.0f, -1.0f, 1.0f, /**/ -1.0f,  1.0f, 1.0f, /**/ -1.0f,  1.0f, 1.0f, /**/ 1.0f, -1.0f, 1.0f, /**/ 1.0f,  1.0f, 1.0f };
+  const QVector<float> vert = { -1.0f, -1.0f, 1.0f, /**/ 1.0f, -1.0f, 1.0f, /**/ -1.0f, 1.0f, 1.0f, /**/ -1.0f, 1.0f, 1.0f, /**/ 1.0f, -1.0f, 1.0f, /**/ 1.0f, 1.0f, 1.0f };
 
   const QByteArray vertexArr( ( const char * ) vert.constData(), vert.size() * sizeof( float ) );
   Qt3DQBuffer *vertexBuffer = nullptr;
@@ -628,7 +631,6 @@ QgsFrameGraph::QgsFrameGraph( QSurface *surface, QSize s, Qt3DRender::QCamera *m
   : Qt3DCore::QEntity( root )
   , mSize( s )
 {
-
   // general overview of how the frame graph looks:
   //
   //  +------------------------+    using window or
@@ -679,7 +681,7 @@ QgsFrameGraph::QgsFrameGraph( QSurface *surface, QSize s, Qt3DRender::QCamera *m
 
   mRenderSurfaceSelector = new Qt3DRender::QRenderSurfaceSelector;
 
-  QObject *surfaceObj = dynamic_cast< QObject *  >( surface );
+  QObject *surfaceObj = dynamic_cast<QObject *>( surface );
   Q_ASSERT( surfaceObj );
 
   mRenderSurfaceSelector->setSurface( surfaceObj );
@@ -743,28 +745,27 @@ QgsPreviewQuad *QgsFrameGraph::addTexturePreviewOverlay( Qt3DRender::QTexture2D
   return previewQuad;
 }
 
-// computes the portion of the Y=y plane the camera is looking at
-void calculateViewExtent( Qt3DRender::QCamera *camera, float shadowRenderingDistance, float y, float &minX, float &maxX, float &minY, float &maxY, float &minZ, float &maxZ )
+// computes the portion of the Z=z plane the camera is looking at
+void calculateViewExtent( Qt3DRender::QCamera *camera, float shadowRenderingDistance, float z, float &minX, float &maxX, float &minY, float &maxY, float &minZ, float &maxZ )
 {
   const QVector3D cameraPos = camera->position();
   const QMatrix4x4 projectionMatrix = camera->projectionMatrix();
   const QMatrix4x4 viewMatrix = camera->viewMatrix();
   float depth = 1.0f;
-  QVector4D viewCenter =  viewMatrix * QVector4D( camera->viewCenter(), 1.0f );
+  QVector4D viewCenter = viewMatrix * QVector4D( camera->viewCenter(), 1.0f );
   viewCenter /= viewCenter.w();
   viewCenter = projectionMatrix * viewCenter;
   viewCenter /= viewCenter.w();
   depth = viewCenter.z();
-  QVector<QVector3D> viewFrustumPoints =
-  {
-    QVector3D( 0.0f,  0.0f, depth ),
-    QVector3D( 0.0f,  1.0f, depth ),
-    QVector3D( 1.0f,  0.0f, depth ),
-    QVector3D( 1.0f,  1.0f, depth ),
-    QVector3D( 0.0f,  0.0f, 0 ),
-    QVector3D( 0.0f,  1.0f, 0 ),
-    QVector3D( 1.0f,  0.0f, 0 ),
-    QVector3D( 1.0f,  1.0f, 0 )
+  QVector<QVector3D> viewFrustumPoints = {
+    QVector3D( 0.0f, 0.0f, depth ),
+    QVector3D( 0.0f, 1.0f, depth ),
+    QVector3D( 1.0f, 0.0f, depth ),
+    QVector3D( 1.0f, 1.0f, depth ),
+    QVector3D( 0.0f, 0.0f, 0 ),
+    QVector3D( 0.0f, 1.0f, 0 ),
+    QVector3D( 1.0f, 0.0f, 0 ),
+    QVector3D( 1.0f, 1.0f, 0 )
   };
   maxX = std::numeric_limits<float>::lowest();
   maxY = std::numeric_limits<float>::lowest();
@@ -783,12 +784,12 @@ void calculateViewExtent( Qt3DRender::QCamera *camera, float shadowRenderingDist
     minZ = std::min( minZ, viewFrustumPoints[i].z() );
     maxZ = std::max( maxZ, viewFrustumPoints[i].z() );
     // find the intersection between the line going from cameraPos to the frustum quad point
-    // and the horizontal plane Y=y
+    // and the horizontal plane Z=z
     // if the intersection is on the back side of the viewing panel we get a point that is
     // shadowRenderingDistance units in front of the camera
     const QVector3D pt = cameraPos;
     const QVector3D vect = ( viewFrustumPoints[i] - pt ).normalized();
-    float t = ( y - pt.y() ) / vect.y();
+    float t = ( z - pt.z() ) / vect.z();
     if ( t < 0 )
       t = shadowRenderingDistance;
     else
@@ -809,24 +810,24 @@ void QgsFrameGraph::setupDirectionalLight( const QgsDirectionalLightSettings &li
   QVector3D lookingAt = mMainCamera->viewCenter();
   const float d = 2 * ( mMainCamera->position() - mMainCamera->viewCenter() ).length();
 
-  const QVector3D vertical = QVector3D( 0.0f, d, 0.0f );
   const QVector3D lightDirection = QVector3D( light.direction().x(), light.direction().y(), light.direction().z() ).normalized();
-  calculateViewExtent( mMainCamera, maximumShadowRenderingDistance, lookingAt.y(), minX, maxX, minY, maxY, minZ, maxZ );
+  calculateViewExtent( mMainCamera, maximumShadowRenderingDistance, lookingAt.z(), minX, maxX, minY, maxY, minZ, maxZ );
 
-  lookingAt = QVector3D( 0.5 * ( minX + maxX ), mMainCamera->viewCenter().y(), 0.5 * ( minZ + maxZ ) );
-  const QVector3D lightPosition = lookingAt + vertical;
+  lookingAt = QVector3D( 0.5f * ( minX + maxX ), 0.5f * ( minY + maxY ), mMainCamera->viewCenter().z() );
+  const QVector3D lightPosition = lookingAt + QVector3D( 0.0f, 0.0f, d );
   mLightCamera->setPosition( lightPosition );
   mLightCamera->setViewCenter( lookingAt );
   mLightCamera->setUpVector( QVector3D( 0.0f, 1.0f, 0.0f ) );
-  mLightCamera->rotateAboutViewCenter( QQuaternion::rotationTo( vertical.normalized(), -lightDirection.normalized() ) );
+  mLightCamera->rotateAboutViewCenter( QQuaternion::rotationTo( QVector3D( 0.0f, 0.0f, -1.0f ), lightDirection ) );
 
   mLightCamera->setProjectionType( Qt3DRender::QCameraLens::ProjectionType::OrthographicProjection );
   mLightCamera->lens()->setOrthographicProjection(
-    - 0.7 * ( maxX - minX ), 0.7 * ( maxX - minX ),
-    - 0.7 * ( maxZ - minZ ), 0.7 * ( maxZ - minZ ),
-    1.0f, 2 * ( lookingAt - lightPosition ).length() );
+    -0.7f * ( maxX - minX ), 0.7f * ( maxX - minX ),
+    -0.7f * ( maxY - minY ), 0.7f * ( maxY - minY ),
+    1.0f, 2 * ( lookingAt - lightPosition ).length()
+  );
 
-  mPostprocessingEntity->setupShadowRenderingExtent( minX, maxX, minZ, maxZ );
+  mPostprocessingEntity->setupShadowRenderingExtent( minX, maxX, minY, maxY );
   mPostprocessingEntity->setupDirectionalLight( lightPosition, lightDirection );
 }
 
@@ -910,7 +911,7 @@ void QgsFrameGraph::setFrustumCullingEnabled( bool enabled )
   if ( mFrustumCullingEnabled )
     mFrustumCulling->setParent( mForwardClearBuffers );
   else
-    mFrustumCulling->setParent( ( Qt3DCore::QNode * )nullptr );
+    mFrustumCulling->setParent( ( Qt3DCore::QNode * ) nullptr );
 }
 
 void QgsFrameGraph::setupEyeDomeLighting( bool enabled, double strength, int distance )
@@ -1021,5 +1022,4 @@ void QgsFrameGraph::addClipPlanes( int nrClipPlanes )
     clipPlane->setPlaneIndex( i );
     mClipRenderStateSet->addRenderState( clipPlane );
   }
-
 }
