@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgspointcloud3dsymbol_p.h"
+#include "moc_qgspointcloud3dsymbol_p.cpp"
 
 ///@cond PRIVATE
 
@@ -24,11 +25,12 @@
 #include "qgspointcloudblockrequest.h"
 #include "qgsfeedback.h"
 #include "qgsaabb.h"
+#include "qgsgeotransform.h"
 
 #include <Qt3DCore/QEntity>
 #include <Qt3DRender/QGeometryRenderer>
 #include <Qt3DRender/QParameter>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
 #include <Qt3DRender/QAttribute>
 #include <Qt3DRender/QBuffer>
 #include <Qt3DRender/QGeometry>
@@ -55,15 +57,12 @@ typedef Qt3DCore::QGeometry Qt3DQGeometry;
 #include <delaunator.hpp>
 
 // pick a point that we'll use as origin for coordinates for this node's points
-static QgsVector3D originFromNodeBounds( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context, const QgsPointCloudBlock *block )
+static QgsVector3D originFromNodeBounds( QgsPointCloudIndex &pc, const QgsPointCloudNodeId &n, const QgsPointCloud3DRenderContext &context )
 {
-  const QgsVector3D blockScale = block->scale();
-  const QgsVector3D blockOffset = block->offset();
-
-  QgsPointCloudDataBounds bounds = pc->nodeBounds( n );
-  double nodeOriginX = bounds.xMin() * blockScale.x() + blockOffset.x();
-  double nodeOriginY = bounds.yMin() * blockScale.y() + blockOffset.y();
-  double nodeOriginZ = ( bounds.zMin() * blockScale.z() + blockOffset.z() ) * context.zValueScale() + context.zValueFixedOffset();
+  QgsBox3D bounds = pc.getNode( n ).bounds();
+  double nodeOriginX = bounds.xMinimum();
+  double nodeOriginY = bounds.yMinimum();
+  double nodeOriginZ = bounds.zMinimum() * context.zValueScale() + context.zValueFixedOffset();
   try
   {
     context.coordinateTransform().transformInPlace( nodeOriginX, nodeOriginY, nodeOriginZ );
@@ -89,7 +88,7 @@ QgsPointCloud3DGeometry::QgsPointCloud3DGeometry( Qt3DCore::QNode *parent, const
 {
   if ( !data.triangles.isEmpty() )
   {
-    mTriangleBuffer = new  Qt3DQBuffer( this );
+    mTriangleBuffer = new Qt3DQBuffer( this );
     mTriangleIndexAttribute->setAttributeType( Qt3DQAttribute::IndexAttribute );
     mTriangleIndexAttribute->setBuffer( mTriangleBuffer );
     mTriangleIndexAttribute->setVertexBaseType( Qt3DQAttribute::UnsignedInt );
@@ -292,10 +291,10 @@ void QgsPointCloud3DSymbolHandler::makeEntity( Qt3DCore::QEntity *parent, const
   // Geometry
   Qt3DQGeometry *geom = makeGeometry( parent, out, context.symbol()->byteStride() );
   Qt3DRender::QGeometryRenderer *gr = new Qt3DRender::QGeometryRenderer;
-  if ( context.symbol()->renderAsTriangles() && ! out.triangles.isEmpty() )
+  if ( context.symbol()->renderAsTriangles() && !out.triangles.isEmpty() )
   {
     gr->setPrimitiveType( Qt3DRender::QGeometryRenderer::Triangles );
-    gr->setVertexCount( out.triangles.size() /  sizeof( quint32 ) );
+    gr->setVertexCount( out.triangles.size() / sizeof( quint32 ) );
   }
   else
   {
@@ -306,10 +305,8 @@ void QgsPointCloud3DSymbolHandler::makeEntity( Qt3DCore::QEntity *parent, const
 
   // Transform: chunks are using coordinates relative to chunk origin, with X,Y,Z axes being the same
   // as map coordinates, so we need to rotate and translate entities to get them into world coordinates
-  Qt3DCore::QTransform *tr = new Qt3DCore::QTransform;
-  QVector3D nodeTranslation = ( out.positionsOrigin - context.origin() ).toVector3D();
-  tr->setRotation( QQuaternion::fromAxisAndAngle( QVector3D( 1, 0, 0 ), -90 ) ); // flip map (x,y,z) to world (x,z,-y)
-  tr->setTranslation( QVector3D( nodeTranslation.x(), nodeTranslation.z(), -nodeTranslation.y() ) );
+  QgsGeoTransform *tr = new QgsGeoTransform;
+  tr->setGeoTranslation( out.positionsOrigin );
 
   // Material
   QgsMaterial *mat = new QgsMaterial;
@@ -326,7 +323,7 @@ void QgsPointCloud3DSymbolHandler::makeEntity( Qt3DCore::QEntity *parent, const
   if ( out.triangles.isEmpty() )
   {
     Qt3DRender::QPointSize *pointSize = new Qt3DRender::QPointSize( renderPass );
-    pointSize->setSizeMode( Qt3DRender::QPointSize::Programmable );  // supported since OpenGL 3.2
+    pointSize->setSizeMode( Qt3DRender::QPointSize::Programmable ); // supported since OpenGL 3.2
     renderPass->addRenderState( pointSize );
   }
 
@@ -359,9 +356,8 @@ void QgsPointCloud3DSymbolHandler::makeEntity( Qt3DCore::QEntity *parent, const
 }
 
 
-std::vector<double> QgsPointCloud3DSymbolHandler::getVertices( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context, const QgsAABB &bbox )
+std::vector<double> QgsPointCloud3DSymbolHandler::getVertices( QgsPointCloudIndex &pc, const QgsPointCloudNodeId &n, const QgsPointCloud3DRenderContext &context, const QgsBox3D &box3D )
 {
-
   bool hasColorData = !outNormal.colors.empty();
   bool hasParameterData = !outNormal.parameter.empty();
   bool hasPointSizeData = !outNormal.pointSizes.empty();
@@ -372,21 +368,20 @@ std::vector<double> QgsPointCloud3DSymbolHandler::getVertices( QgsPointCloudInde
   for ( int i = 0; i < outNormal.positions.size(); ++i )
   {
     vertices[idx++] = outNormal.positions.at( i ).x();
-    vertices[idx++] = -outNormal.positions.at( i ).y();  // flipping y to have correctly oriented triangles from delaunator
+    vertices[idx++] = -outNormal.positions.at( i ).y(); // flipping y to have correctly oriented triangles from delaunator
   }
 
   // next, we also need all points of all parents nodes to make the triangulation (also external points)
-  IndexedPointCloudNode parentNode = n.parentNode();
+  QgsPointCloudNodeId parentNode = n.parentNode();
 
-  double span = pc->span();
+  double span = pc.span();
   //factor to take account of the density of the point to calculate extension of the bounding box
   // with a usual value span = 128, bounding box is extended by 12.5 % on each side.
   double extraBoxFactor = 16 / span;
-  double extraX = extraBoxFactor * bbox.xExtent();
-  double extraY = extraBoxFactor * bbox.yExtent();
 
   // We keep all points in vertical direction to avoid odd triangulation if points are isolated on top
-  const QgsAABB extendedBBox( bbox.xMin - extraX, bbox.yMin - extraY, -std::numeric_limits<float>::max(), bbox.xMax + extraX, bbox.yMax + extraY, std::numeric_limits<float>::max() );
+  QgsRectangle rectRelativeToChunkOrigin = ( box3D - outNormal.positionsOrigin ).toRectangle();
+  rectRelativeToChunkOrigin.grow( extraBoxFactor * std::max( box3D.width(), box3D.height() ) );
 
   PointData filteredExtraPointData;
   while ( parentNode.d() >= 0 )
@@ -400,11 +395,11 @@ std::vector<double> QgsPointCloud3DSymbolHandler::getVertices( QgsPointCloudInde
     for ( int i = 0; i < outputParent.positions.count(); ++i )
     {
       const QVector3D pos = outputParent.positions.at( i ) + originDifference;
-      if ( extendedBBox.intersects( pos.x(), pos.y(), pos.z() ) )
+      if ( rectRelativeToChunkOrigin.contains( pos.x(), pos.y() ) )
       {
         filteredExtraPointData.positions.append( pos );
         vertices.push_back( pos.x() );
-        vertices.push_back( -pos.y() );  // flipping y to have correctly oriented triangles from delaunator
+        vertices.push_back( -pos.y() ); // flipping y to have correctly oriented triangles from delaunator
 
         if ( hasColorData )
           filteredExtraPointData.colors.append( outputParent.colors.at( i ) );
@@ -440,8 +435,9 @@ void QgsPointCloud3DSymbolHandler::calculateNormals( const std::vector<size_t> &
     //calculate normals
     for ( size_t j = 0; j < 3; ++j )
       normals[triangles.at( i + j )] += QVector3D::crossProduct(
-                                          triangleVertices.at( 1 ) - triangleVertices.at( 0 ),
-                                          triangleVertices.at( 2 ) - triangleVertices.at( 0 ) );
+        triangleVertices.at( 1 ) - triangleVertices.at( 0 ),
+        triangleVertices.at( 2 ) - triangleVertices.at( 0 )
+      );
   }
 
   // Build now normals array
@@ -458,7 +454,7 @@ void QgsPointCloud3DSymbolHandler::calculateNormals( const std::vector<size_t> &
   }
 }
 
-void QgsPointCloud3DSymbolHandler::filterTriangles( const std::vector<size_t> &triangleIndexes, const QgsPointCloud3DRenderContext &context, const QgsAABB &bbox )
+void QgsPointCloud3DSymbolHandler::filterTriangles( const std::vector<size_t> &triangleIndexes, const QgsPointCloud3DRenderContext &context, const QgsBox3D &box3D )
 {
   outNormal.triangles.resize( triangleIndexes.size() * sizeof( quint32 ) );
   quint32 *indexPtr = reinterpret_cast<quint32 *>( outNormal.triangles.data() );
@@ -466,8 +462,10 @@ void QgsPointCloud3DSymbolHandler::filterTriangles( const std::vector<size_t> &t
 
   bool horizontalFilter = context.symbol()->horizontalTriangleFilter();
   bool verticalFilter = context.symbol()->verticalTriangleFilter();
-  float horizontalThreshold =  context.symbol()->horizontalFilterThreshold();
-  float verticalThreshold =  context.symbol()->verticalFilterThreshold();
+  float horizontalThreshold = context.symbol()->horizontalFilterThreshold();
+  float verticalThreshold = context.symbol()->verticalFilterThreshold();
+
+  QgsBox3D boxRelativeToChunkOrigin = box3D - outNormal.positionsOrigin;
 
   for ( size_t i = 0; i < triangleIndexes.size(); i += 3 )
   {
@@ -476,8 +474,8 @@ void QgsPointCloud3DSymbolHandler::filterTriangles( const std::vector<size_t> &t
     bool verticalSkip = false;
     for ( size_t j = 0; j < 3; j++ )
     {
-      QVector3D pos = outNormal.positions.at( triangleIndexes.at( i  + j ) );
-      atLeastOneInBox |= bbox.intersects( pos.x(), pos.y(), pos.z() );
+      QVector3D pos = outNormal.positions.at( triangleIndexes.at( i + j ) );
+      atLeastOneInBox |= boxRelativeToChunkOrigin.contains( pos.x(), pos.y(), pos.z() );
 
       if ( verticalFilter || horizontalFilter )
       {
@@ -486,11 +484,10 @@ void QgsPointCloud3DSymbolHandler::filterTriangles( const std::vector<size_t> &t
         if ( verticalFilter )
           verticalSkip |= std::fabs( pos.z() - pos2.z() ) > verticalThreshold;
 
-        if ( horizontalFilter && ! verticalSkip )
+        if ( horizontalFilter && !verticalSkip )
         {
           // filter only in the horizontal plan, it is a 2.5D triangulation.
-          horizontalSkip |= sqrt( std::pow( pos.x() - pos2.x(), 2 ) +
-                                  std::pow( pos.y() - pos2.y(), 2 ) ) > horizontalThreshold;
+          horizontalSkip |= sqrt( std::pow( pos.x() - pos2.x(), 2 ) + std::pow( pos.y() - pos2.y(), 2 ) ) > horizontalThreshold;
         }
 
         if ( horizontalSkip || verticalSkip )
@@ -519,30 +516,16 @@ void QgsPointCloud3DSymbolHandler::filterTriangles( const std::vector<size_t> &t
   }
 }
 
-void QgsPointCloud3DSymbolHandler::triangulate( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context, const QgsAABB &bbox )
+void QgsPointCloud3DSymbolHandler::triangulate( QgsPointCloudIndex &pc, const QgsPointCloudNodeId &n, const QgsPointCloud3DRenderContext &context, const QgsBox3D &box3D )
 {
   if ( outNormal.positions.isEmpty() )
     return;
 
-  // The bbox we get is in world coordinates, we need to transform it to map coordinates
-  // (flip axes and add scene origin vector), but relative to the chunk's origin (subtract it)
-  // because that's the coordinate system used within the chunk
-  QgsBox3D boxRelativeToChunkOrigin(
-    bbox.xMin + context.origin().x() - outNormal.positionsOrigin.x(),
-    -bbox.zMax + context.origin().y() - outNormal.positionsOrigin.y(),
-    bbox.yMin + context.origin().z() - outNormal.positionsOrigin.z(),
-    bbox.xMax + context.origin().x() - outNormal.positionsOrigin.x(),
-    -bbox.zMin + context.origin().y() - outNormal.positionsOrigin.y(),
-    bbox.yMax + context.origin().z() - outNormal.positionsOrigin.z() );
-  QgsAABB aabbRelativeToChunkOrigin(
-    boxRelativeToChunkOrigin.xMinimum(), boxRelativeToChunkOrigin.yMinimum(), boxRelativeToChunkOrigin.zMinimum(),
-    boxRelativeToChunkOrigin.xMaximum(), boxRelativeToChunkOrigin.yMaximum(), boxRelativeToChunkOrigin.zMaximum() );
-
   // Triangulation happens here
   std::unique_ptr<delaunator::Delaunator> triangulation;
   try
   {
-    std::vector<double> vertices = getVertices( pc, n, context, aabbRelativeToChunkOrigin );
+    std::vector<double> vertices = getVertices( pc, n, context, box3D );
     triangulation.reset( new delaunator::Delaunator( vertices ) );
   }
   catch ( std::exception &e )
@@ -557,27 +540,27 @@ void QgsPointCloud3DSymbolHandler::triangulate( QgsPointCloudIndex *pc, const In
   const std::vector<size_t> &triangleIndexes = triangulation->triangles;
 
   calculateNormals( triangleIndexes );
-  filterTriangles( triangleIndexes, context, aabbRelativeToChunkOrigin );
+  filterTriangles( triangleIndexes, context, box3D );
 }
 
-std::unique_ptr<QgsPointCloudBlock> QgsPointCloud3DSymbolHandler::pointCloudBlock( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloudRequest &request, const QgsPointCloud3DRenderContext &context )
+std::unique_ptr<QgsPointCloudBlock> QgsPointCloud3DSymbolHandler::pointCloudBlock( QgsPointCloudIndex &pc, const QgsPointCloudNodeId &n, const QgsPointCloudRequest &request, const QgsPointCloud3DRenderContext &context )
 {
   std::unique_ptr<QgsPointCloudBlock> block;
-  if ( pc->accessType() == QgsPointCloudIndex::AccessType::Local )
+  if ( pc.accessType() == Qgis::PointCloudAccessType::Local )
   {
-    block = pc->nodeData( n, request );
+    block = pc.nodeData( n, request );
   }
-  else if ( pc->accessType() == QgsPointCloudIndex::AccessType::Remote )
+  else if ( pc.accessType() == Qgis::PointCloudAccessType::Remote )
   {
-    if ( pc->nodePointCount( n ) < 1 )
+    QgsPointCloudNode node = pc.getNode( n );
+    if ( node.pointCount() < 1 )
       return block;
 
     bool loopAborted = false;
     QEventLoop loop;
-    QgsPointCloudBlockRequest *req = pc->asyncNodeData( n, request );
+    QgsPointCloudBlockRequest *req = pc.asyncNodeData( n, request );
     QObject::connect( req, &QgsPointCloudBlockRequest::finished, &loop, &QEventLoop::quit );
-    QObject::connect( context.feedback(), &QgsFeedback::canceled, &loop, [ & ]()
-    {
+    QObject::connect( context.feedback(), &QgsFeedback::canceled, &loop, [&]() {
       loopAborted = true;
       loop.quit();
     } );
@@ -594,7 +577,6 @@ std::unique_ptr<QgsPointCloudBlock> QgsPointCloud3DSymbolHandler::pointCloudBloc
 QgsSingleColorPointCloud3DSymbolHandler::QgsSingleColorPointCloud3DSymbolHandler()
   : QgsPointCloud3DSymbolHandler()
 {
-
 }
 
 bool QgsSingleColorPointCloud3DSymbolHandler::prepare( const QgsPointCloud3DRenderContext &context )
@@ -603,7 +585,7 @@ bool QgsSingleColorPointCloud3DSymbolHandler::prepare( const QgsPointCloud3DRend
   return true;
 }
 
-void QgsSingleColorPointCloud3DSymbolHandler::processNode( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context, PointData *output )
+void QgsSingleColorPointCloud3DSymbolHandler::processNode( QgsPointCloudIndex &pc, const QgsPointCloudNodeId &n, const QgsPointCloud3DRenderContext &context, PointData *output )
 {
   QgsPointCloudAttributeCollection attributes;
   attributes.push_back( QgsPointCloudAttribute( QStringLiteral( "X" ), QgsPointCloudAttribute::Int32 ) );
@@ -630,16 +612,16 @@ void QgsSingleColorPointCloud3DSymbolHandler::processNode( QgsPointCloudIndex *p
   if ( !output )
     output = &outNormal;
 
-  output->positionsOrigin = originFromNodeBounds( pc, n, context, block.get() );
+  output->positionsOrigin = originFromNodeBounds( pc, n, context );
 
   for ( int i = 0; i < count; ++i )
   {
     if ( context.isCanceled() )
       break;
 
-    const qint32 ix = *( qint32 * )( ptr + i * recordSize + 0 );
-    const qint32 iy = *( qint32 * )( ptr + i * recordSize + 4 );
-    const qint32 iz = *( qint32 * )( ptr + i * recordSize + 8 );
+    const qint32 ix = *( qint32 * ) ( ptr + i * recordSize + 0 );
+    const qint32 iy = *( qint32 * ) ( ptr + i * recordSize + 4 );
+    const qint32 iz = *( qint32 * ) ( ptr + i * recordSize + 8 );
 
     double x = blockOffset.x() + blockScale.x() * ix;
     double y = blockOffset.y() + blockScale.y() * iy;
@@ -674,7 +656,6 @@ Qt3DQGeometry *QgsSingleColorPointCloud3DSymbolHandler::makeGeometry( Qt3DCore::
 QgsColorRampPointCloud3DSymbolHandler::QgsColorRampPointCloud3DSymbolHandler()
   : QgsPointCloud3DSymbolHandler()
 {
-
 }
 
 bool QgsColorRampPointCloud3DSymbolHandler::prepare( const QgsPointCloud3DRenderContext &context )
@@ -683,7 +664,7 @@ bool QgsColorRampPointCloud3DSymbolHandler::prepare( const QgsPointCloud3DRender
   return true;
 }
 
-void QgsColorRampPointCloud3DSymbolHandler::processNode( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context, PointData *output )
+void QgsColorRampPointCloud3DSymbolHandler::processNode( QgsPointCloudIndex &pc, const QgsPointCloudNodeId &n, const QgsPointCloud3DRenderContext &context, PointData *output )
 {
   QgsPointCloudAttributeCollection attributes;
   const int xOffset = 0;
@@ -755,16 +736,16 @@ void QgsColorRampPointCloud3DSymbolHandler::processNode( QgsPointCloudIndex *pc,
   if ( !output )
     output = &outNormal;
 
-  output->positionsOrigin = originFromNodeBounds( pc, n, context, block.get() );
+  output->positionsOrigin = originFromNodeBounds( pc, n, context );
 
   for ( int i = 0; i < count; ++i )
   {
     if ( context.isCanceled() )
       break;
 
-    const qint32 ix = *( qint32 * )( ptr + i * recordSize + xOffset );
-    const qint32 iy = *( qint32 * )( ptr + i * recordSize + yOffset );
-    const qint32 iz = *( qint32 * )( ptr + i * recordSize + zOffset );
+    const qint32 ix = *( qint32 * ) ( ptr + i * recordSize + xOffset );
+    const qint32 iy = *( qint32 * ) ( ptr + i * recordSize + yOffset );
+    const qint32 iz = *( qint32 * ) ( ptr + i * recordSize + zOffset );
 
     double x = blockOffset.x() + blockScale.x() * ix;
     double y = blockOffset.y() + blockScale.y() * iy;
@@ -812,7 +793,6 @@ Qt3DQGeometry *QgsColorRampPointCloud3DSymbolHandler::makeGeometry( Qt3DCore::QN
 QgsRGBPointCloud3DSymbolHandler::QgsRGBPointCloud3DSymbolHandler()
   : QgsPointCloud3DSymbolHandler()
 {
-
 }
 
 bool QgsRGBPointCloud3DSymbolHandler::prepare( const QgsPointCloud3DRenderContext &context )
@@ -821,17 +801,17 @@ bool QgsRGBPointCloud3DSymbolHandler::prepare( const QgsPointCloud3DRenderContex
   return true;
 }
 
-void QgsRGBPointCloud3DSymbolHandler::processNode( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context, PointData *output )
+void QgsRGBPointCloud3DSymbolHandler::processNode( QgsPointCloudIndex &pc, const QgsPointCloudNodeId &n, const QgsPointCloud3DRenderContext &context, PointData *output )
 {
   QgsPointCloudAttributeCollection attributes;
   attributes.push_back( QgsPointCloudAttribute( QStringLiteral( "X" ), QgsPointCloudAttribute::Int32 ) );
   attributes.push_back( QgsPointCloudAttribute( QStringLiteral( "Y" ), QgsPointCloudAttribute::Int32 ) );
   attributes.push_back( QgsPointCloudAttribute( QStringLiteral( "Z" ), QgsPointCloudAttribute::Int32 ) );
 
-  QgsRgbPointCloud3DSymbol *symbol = dynamic_cast<QgsRgbPointCloud3DSymbol *>( context.symbol() );
+  QgsRgbPointCloud3DSymbol *symbol = qgis::down_cast<QgsRgbPointCloud3DSymbol *>( context.symbol() );
 
   // we have to get the RGB attributes using their real data types -- they aren't always short! (sometimes unsigned short)
-  int attrOffset = 0 ;
+  int attrOffset = 0;
 
   const int redOffset = attributes.pointRecordSize();
   const QgsPointCloudAttribute *colorAttribute = context.attributes().find( symbol->redAttribute(), attrOffset );
@@ -877,7 +857,7 @@ void QgsRGBPointCloud3DSymbolHandler::processNode( QgsPointCloudIndex *pc, const
   if ( !output )
     output = &outNormal;
 
-  output->positionsOrigin = originFromNodeBounds( pc, n, context, block.get() );
+  output->positionsOrigin = originFromNodeBounds( pc, n, context );
 
   int ir = 0;
   int ig = 0;
@@ -887,9 +867,9 @@ void QgsRGBPointCloud3DSymbolHandler::processNode( QgsPointCloudIndex *pc, const
     if ( context.isCanceled() )
       break;
 
-    const qint32 ix = *( qint32 * )( ptr + i * recordSize + 0 );
-    const qint32 iy = *( qint32 * )( ptr + i * recordSize + 4 );
-    const qint32 iz = *( qint32 * )( ptr + i * recordSize + 8 );
+    const qint32 ix = *( qint32 * ) ( ptr + i * recordSize + 0 );
+    const qint32 iy = *( qint32 * ) ( ptr + i * recordSize + 4 );
+    const qint32 iz = *( qint32 * ) ( ptr + i * recordSize + 8 );
     double x = blockOffset.x() + blockScale.x() * ix;
     double y = blockOffset.y() + blockScale.y() * iy;
     double z = ( blockOffset.z() + blockScale.z() * iz ) * zValueScale + zValueOffset;
@@ -957,7 +937,6 @@ Qt3DQGeometry *QgsRGBPointCloud3DSymbolHandler::makeGeometry( Qt3DCore::QNode *p
 QgsClassificationPointCloud3DSymbolHandler::QgsClassificationPointCloud3DSymbolHandler()
   : QgsPointCloud3DSymbolHandler()
 {
-
 }
 
 bool QgsClassificationPointCloud3DSymbolHandler::prepare( const QgsPointCloud3DRenderContext &context )
@@ -966,7 +945,7 @@ bool QgsClassificationPointCloud3DSymbolHandler::prepare( const QgsPointCloud3DR
   return true;
 }
 
-void QgsClassificationPointCloud3DSymbolHandler::processNode( QgsPointCloudIndex *pc, const IndexedPointCloudNode &n, const QgsPointCloud3DRenderContext &context, PointData *output )
+void QgsClassificationPointCloud3DSymbolHandler::processNode( QgsPointCloudIndex &pc, const QgsPointCloudNodeId &n, const QgsPointCloud3DRenderContext &context, PointData *output )
 {
   QgsPointCloudAttributeCollection attributes;
   const int xOffset = 0;
@@ -983,33 +962,33 @@ void QgsClassificationPointCloud3DSymbolHandler::processNode( QgsPointCloudIndex
   QgsPointCloudAttribute::DataType attributeType = QgsPointCloudAttribute::Float;
   int attributeOffset = 0;
   QgsClassificationPointCloud3DSymbol *symbol = dynamic_cast<QgsClassificationPointCloud3DSymbol *>( context.symbol() );
-  if ( symbol )
-  {
-    int offset = 0;
-    const QgsPointCloudAttributeCollection collection = context.attributes();
+  if ( !symbol )
+    return;
 
-    if ( symbol->attribute() == QLatin1String( "X" ) )
+  int offset = 0;
+  const QgsPointCloudAttributeCollection collection = context.attributes();
+
+  if ( symbol->attribute() == QLatin1String( "X" ) )
+  {
+    attrIsX = true;
+  }
+  else if ( symbol->attribute() == QLatin1String( "Y" ) )
+  {
+    attrIsY = true;
+  }
+  else if ( symbol->attribute() == QLatin1String( "Z" ) )
+  {
+    attrIsZ = true;
+  }
+  else
+  {
+    const QgsPointCloudAttribute *attr = collection.find( symbol->attribute(), offset );
+    if ( attr )
     {
-      attrIsX = true;
-    }
-    else if ( symbol->attribute() == QLatin1String( "Y" ) )
-    {
-      attrIsY = true;
-    }
-    else if ( symbol->attribute() == QLatin1String( "Z" ) )
-    {
-      attrIsZ = true;
-    }
-    else
-    {
-      const QgsPointCloudAttribute *attr = collection.find( symbol->attribute(), offset );
-      if ( attr )
-      {
-        attributeType = attr->type();
-        attributeName = attr->name();
-        attributeOffset = attributes.pointRecordSize();
-        attributes.push_back( *attr );
-      }
+      attributeType = attr->type();
+      attributeName = attr->name();
+      attributeOffset = attributes.pointRecordSize();
+      attributes.push_back( *attr );
     }
   }
 
@@ -1040,14 +1019,14 @@ void QgsClassificationPointCloud3DSymbolHandler::processNode( QgsPointCloudIndex
   for ( QgsPointCloudCategory &c : categoriesList )
   {
     categoriesValues.push_back( c.value() );
-    categoriesPointSizes.insert( c.value(), c.pointSize() > 0 ? c.pointSize() :
-                                 context.symbol() ? context.symbol()->pointSize() : 1.0 );
+    categoriesPointSizes.insert( c.value(), c.pointSize() > 0 ? c.pointSize() : context.symbol() ? context.symbol()->pointSize()
+                                                                                                 : 1.0 );
   }
 
   if ( !output )
     output = &outNormal;
 
-  output->positionsOrigin = originFromNodeBounds( pc, n, context, block.get() );
+  output->positionsOrigin = originFromNodeBounds( pc, n, context );
 
   const QSet<int> filteredOutValues = context.getFilteredOutValues();
   for ( int i = 0; i < count; ++i )
@@ -1055,9 +1034,9 @@ void QgsClassificationPointCloud3DSymbolHandler::processNode( QgsPointCloudIndex
     if ( context.isCanceled() )
       break;
 
-    const qint32 ix = *( qint32 * )( ptr + i * recordSize + xOffset );
-    const qint32 iy = *( qint32 * )( ptr + i * recordSize + yOffset );
-    const qint32 iz = *( qint32 * )( ptr + i * recordSize + zOffset );
+    const qint32 ix = *( qint32 * ) ( ptr + i * recordSize + xOffset );
+    const qint32 iy = *( qint32 * ) ( ptr + i * recordSize + yOffset );
+    const qint32 iz = *( qint32 * ) ( ptr + i * recordSize + zOffset );
 
     double x = blockOffset.x() + blockScale.x() * ix;
     double y = blockOffset.y() + blockScale.y() * iy;
@@ -1085,13 +1064,12 @@ void QgsClassificationPointCloud3DSymbolHandler::processNode( QgsPointCloudIndex
     else
       context.getAttribute( ptr, i * recordSize + attributeOffset, attributeType, iParam );
 
-    if ( filteredOutValues.contains( ( int ) iParam ) ||
-         ! categoriesValues.contains( ( int ) iParam ) )
+    if ( filteredOutValues.contains( ( int ) iParam ) || !categoriesValues.contains( ( int ) iParam ) )
       continue;
     output->positions.push_back( point.toVector3D() );
 
     // find iParam actual index in the categories list
-    float iParam2 = categoriesValues.indexOf( ( int )iParam ) + 1;
+    float iParam2 = categoriesValues.indexOf( ( int ) iParam ) + 1;
     output->parameter.push_back( iParam2 );
     output->pointSizes.push_back( categoriesPointSizes.value( ( int ) iParam ) );
   }
