@@ -73,7 +73,7 @@ Qgis::ProcessingAlgorithmDocumentationFlags QgsPointsAlongGeometryAlgorithm::doc
 
 QList<int> QgsPointsAlongGeometryAlgorithm::inputLayerTypes() const
 {
-  return QList<int>() << static_cast< int >( Qgis::ProcessingSourceType::VectorLine ) << static_cast< int >( Qgis::ProcessingSourceType::VectorPolygon );
+  return QList<int>() << static_cast<int>( Qgis::ProcessingSourceType::VectorLine ) << static_cast<int>( Qgis::ProcessingSourceType::VectorPolygon );
 }
 
 Qgis::ProcessingSourceType QgsPointsAlongGeometryAlgorithm::outputLayerType() const
@@ -106,22 +106,19 @@ QgsPointsAlongGeometryAlgorithm *QgsPointsAlongGeometryAlgorithm::createInstance
 
 void QgsPointsAlongGeometryAlgorithm::initParameters( const QVariantMap & )
 {
-  std::unique_ptr< QgsProcessingParameterDistance> distance = std::make_unique< QgsProcessingParameterDistance >( QStringLiteral( "DISTANCE" ),
-      QObject::tr( "Distance" ), 1.0, QStringLiteral( "INPUT" ), false, 0 );
+  auto distance = std::make_unique<QgsProcessingParameterDistance>( QStringLiteral( "DISTANCE" ), QObject::tr( "Distance" ), 1.0, QStringLiteral( "INPUT" ), false, 0 );
   distance->setIsDynamic( true );
   distance->setDynamicPropertyDefinition( QgsPropertyDefinition( QStringLiteral( "DISTANCE" ), QObject::tr( "Distance" ), QgsPropertyDefinition::DoublePositive ) );
   distance->setDynamicLayerParameterName( QStringLiteral( "INPUT" ) );
   addParameter( distance.release() );
 
-  std::unique_ptr< QgsProcessingParameterDistance> startOffset = std::make_unique< QgsProcessingParameterDistance >( QStringLiteral( "START_OFFSET" ),
-      QObject::tr( "Start offset" ), 0.0, QStringLiteral( "INPUT" ), false, 0 );
+  auto startOffset = std::make_unique<QgsProcessingParameterDistance>( QStringLiteral( "START_OFFSET" ), QObject::tr( "Start offset" ), 0.0, QStringLiteral( "INPUT" ), false, 0 );
   startOffset->setIsDynamic( true );
   startOffset->setDynamicPropertyDefinition( QgsPropertyDefinition( QStringLiteral( "START_OFFSET" ), QObject::tr( "Start offset" ), QgsPropertyDefinition::DoublePositive ) );
   startOffset->setDynamicLayerParameterName( QStringLiteral( "INPUT" ) );
   addParameter( startOffset.release() );
 
-  std::unique_ptr< QgsProcessingParameterDistance> endOffset = std::make_unique< QgsProcessingParameterDistance >( QStringLiteral( "END_OFFSET" ),
-      QObject::tr( "End offset" ), 0.0, QStringLiteral( "INPUT" ), false, 0 );
+  auto endOffset = std::make_unique<QgsProcessingParameterDistance>( QStringLiteral( "END_OFFSET" ), QObject::tr( "End offset" ), 0.0, QStringLiteral( "INPUT" ), false, 0 );
   endOffset->setIsDynamic( true );
   endOffset->setDynamicPropertyDefinition( QgsPropertyDefinition( QStringLiteral( "END_OFFSET" ), QObject::tr( "End offset" ), QgsPropertyDefinition::DoublePositive ) );
   endOffset->setDynamicLayerParameterName( QStringLiteral( "INPUT" ) );
@@ -154,17 +151,17 @@ bool QgsPointsAlongGeometryAlgorithm::prepareAlgorithm( const QVariantMap &param
   mDistance = parameterAsDouble( parameters, QStringLiteral( "DISTANCE" ), context );
   mDynamicDistance = QgsProcessingParameters::isDynamic( parameters, QStringLiteral( "DISTANCE" ) );
   if ( mDynamicDistance )
-    mDistanceProperty = parameters.value( QStringLiteral( "DISTANCE" ) ).value< QgsProperty >();
+    mDistanceProperty = parameters.value( QStringLiteral( "DISTANCE" ) ).value<QgsProperty>();
 
   mStartOffset = parameterAsDouble( parameters, QStringLiteral( "START_OFFSET" ), context );
   mDynamicStartOffset = QgsProcessingParameters::isDynamic( parameters, QStringLiteral( "START_OFFSET" ) );
   if ( mDynamicStartOffset )
-    mStartOffsetProperty = parameters.value( QStringLiteral( "START_OFFSET" ) ).value< QgsProperty >();
+    mStartOffsetProperty = parameters.value( QStringLiteral( "START_OFFSET" ) ).value<QgsProperty>();
 
   mEndOffset = parameterAsDouble( parameters, QStringLiteral( "END_OFFSET" ), context );
   mDynamicEndOffset = QgsProcessingParameters::isDynamic( parameters, QStringLiteral( "END_OFFSET" ) );
   if ( mDynamicEndOffset )
-    mEndOffsetProperty = parameters.value( QStringLiteral( "END_OFFSET" ) ).value< QgsProperty >();
+    mEndOffsetProperty = parameters.value( QStringLiteral( "END_OFFSET" ) ).value<QgsProperty>();
 
   return true;
 }
@@ -191,11 +188,11 @@ QgsFeatureList QgsPointsAlongGeometryAlgorithm::processFeature( const QgsFeature
       endOffset = mEndOffsetProperty.valueAsDouble( context.expressionContext(), endOffset );
 
     const double totalLength = geometry.type() == Qgis::GeometryType::Polygon ? geometry.constGet()->perimeter()
-                               : geometry.length() - endOffset;
+                                                                              : geometry.length() - endOffset;
 
     double currentDistance = startOffset;
     QgsFeatureList out;
-    out.reserve( static_cast< int >( std::ceil( ( totalLength - startOffset ) / distance ) ) );
+    out.reserve( static_cast<int>( std::ceil( ( totalLength - startOffset ) / distance ) ) );
     while ( currentDistance <= totalLength )
     {
       const QgsGeometry point = geometry.interpolate( currentDistance );
@@ -222,5 +219,3 @@ QgsFeatureList QgsPointsAlongGeometryAlgorithm::processFeature( const QgsFeature
 }
 
 ///@endcond
-
-
