@@ -15,6 +15,7 @@
  ***************************************************************************/
 
 #include "qgsannotationlayer.h"
+#include "moc_qgsannotationlayer.cpp"
 #include "qgsannotationlayerrenderer.h"
 #include "qgsannotationitem.h"
 #include "qgsannotationitemregistry.h"
@@ -38,14 +39,18 @@ class QgsAnnotationLayerSpatialIndex : public RTree<QString, float, 2, float>
     void insert( const QString &uuid, const QgsRectangle &bounds )
     {
       std::array< float, 4 > scaledBounds = scaleBounds( bounds );
-      this->Insert(
+      float aMin[2]
       {
         scaledBounds[0], scaledBounds[ 1]
-      },
+      };
+      float aMax[2]
       {
-        scaledBounds[2], scaledBounds[3]
-      },
-      uuid );
+        scaledBounds[2], scaledBounds[ 3]
+      };
+      this->Insert(
+        aMin,
+        aMax,
+        uuid );
     }
 
     /**
@@ -57,14 +62,18 @@ class QgsAnnotationLayerSpatialIndex : public RTree<QString, float, 2, float>
     void remove( const QString &uuid, const QgsRectangle &bounds )
     {
       std::array< float, 4 > scaledBounds = scaleBounds( bounds );
-      this->Remove(
+      float aMin[2]
       {
         scaledBounds[0], scaledBounds[ 1]
-      },
+      };
+      float aMax[2]
       {
-        scaledBounds[2], scaledBounds[3]
-      },
-      uuid );
+        scaledBounds[2], scaledBounds[ 3]
+      };
+      this->Remove(
+        aMin,
+        aMax,
+        uuid );
     }
 
     /**
@@ -75,14 +84,17 @@ class QgsAnnotationLayerSpatialIndex : public RTree<QString, float, 2, float>
     bool intersects( const QgsRectangle &bounds, const std::function< bool( const QString &uuid )> &callback ) const
     {
       std::array< float, 4 > scaledBounds = scaleBounds( bounds );
-      this->Search(
+      float aMin[2]
       {
         scaledBounds[0], scaledBounds[ 1]
-      },
+      };
+      float aMax[2]
       {
-        scaledBounds[2], scaledBounds[3]
-      },
-      callback );
+        scaledBounds[2], scaledBounds[ 3]
+      };
+      this->Search(
+        aMin, aMax,
+        callback );
       return true;
     }
 
@@ -319,7 +331,7 @@ QgsAnnotationLayer *QgsAnnotationLayer::clone() const
   QGIS_PROTECT_QOBJECT_THREAD_ACCESS
 
   const QgsAnnotationLayer::LayerOptions options( mTransformContext );
-  std::unique_ptr< QgsAnnotationLayer > layer = std::make_unique< QgsAnnotationLayer >( name(), options );
+  auto layer = std::make_unique< QgsAnnotationLayer >( name(), options );
   QgsMapLayer::clone( layer.get() );
 
   for ( auto it = mItems.constBegin(); it != mItems.constEnd(); ++it )
