@@ -31,8 +31,10 @@ QgsVectorLayerLabelProvider *QgsRuleBasedLabelProvider::createProvider( QgsVecto
 
 bool QgsRuleBasedLabelProvider::prepare( QgsRenderContext &context, QSet<QString> &attributeNames )
 {
-  for ( QgsVectorLayerLabelProvider *provider : std::as_const( mSubProviders ) )
-    provider->setEngine( mEngine );
+  for ( const auto &subprovider : std::as_const( mSubProviders ) )
+  {
+    subprovider.second->setEngine( mEngine );
+  }
 
   // populate sub-providers
   mRules->rootRule()->prepare( context, attributeNames, mSubProviders );
@@ -48,8 +50,10 @@ QList<QgsLabelFeature *> QgsRuleBasedLabelProvider::registerFeature( const QgsFe
 QList<QgsAbstractLabelProvider *> QgsRuleBasedLabelProvider::subProviders()
 {
   QList<QgsAbstractLabelProvider *> lst;
-  for ( QgsVectorLayerLabelProvider *subprovider : std::as_const( mSubProviders ) )
-    lst << subprovider;
+  for ( const auto &subprovider : std::as_const( mSubProviders ) )
+  {
+    lst << subprovider.second;
+  }
   return lst;
 }
 
@@ -229,14 +233,18 @@ QgsRuleBasedLabeling::Rule *QgsRuleBasedLabeling::Rule::findRuleByKey( const QSt
   return nullptr;
 }
 
-QgsRuleBasedLabeling::Rule *QgsRuleBasedLabeling::Rule::clone() const
+QgsRuleBasedLabeling::Rule *QgsRuleBasedLabeling::Rule::clone( bool resetRuleKey ) const
 {
   QgsPalLayerSettings *s = mSettings.get() ? new QgsPalLayerSettings( *mSettings ) : nullptr;
   Rule *newrule = new Rule( s, mMaximumScale, mMinimumScale, mFilterExp, mDescription );
   newrule->setActive( mIsActive );
+  if ( !resetRuleKey )
+    newrule->setRuleKey( ruleKey() );
+
   // clone children
   for ( Rule *rule : mChildren )
-    newrule->appendChild( rule->clone() );
+    newrule->appendChild( rule->clone( resetRuleKey ) );
+
   return newrule;
 }
 
@@ -312,14 +320,25 @@ QDomElement QgsRuleBasedLabeling::Rule::save( QDomDocument &doc, const QgsReadWr
   return ruleElem;
 }
 
-void QgsRuleBasedLabeling::Rule::createSubProviders( QgsVectorLayer *layer, QgsRuleBasedLabeling::RuleToProviderMap &subProviders, QgsRuleBasedLabelProvider *provider )
+void QgsRuleBasedLabeling::Rule::createSubProviders( QgsVectorLayer *layer, QgsRuleBasedLabeling::RuleToProviderVec &subProviders, QgsRuleBasedLabelProvider *provider )
 {
   if ( mSettings )
   {
     // add provider!
     QgsVectorLayerLabelProvider *p = provider->createProvider( layer, mRuleKey, false, mSettings.get() );
-    delete subProviders.value( this, nullptr );
-    subProviders[this] = p;
+    auto it = std::find_if( subProviders.begin(), subProviders.end(),
+                            [this]( const std::pair<QgsRuleBasedLabeling::Rule *, QgsVectorLayerLabelProvider *> &item )
+    {
+      return item.first == this;
+    } );
+
+    if ( it != subProviders.end() )
+    {
+      delete it->second;
+      subProviders.erase( it );
+    }
+
+    subProviders.push_back( {this, p} );
   }
 
   // call recursively
@@ -329,15 +348,24 @@ void QgsRuleBasedLabeling::Rule::createSubProviders( QgsVectorLayer *layer, QgsR
   }
 }
 
-void QgsRuleBasedLabeling::Rule::prepare( QgsRenderContext &context, QSet<QString> &attributeNames, QgsRuleBasedLabeling::RuleToProviderMap &subProviders )
+void QgsRuleBasedLabeling::Rule::prepare( QgsRenderContext &context, QSet<QString> &attributeNames, QgsRuleBasedLabeling::RuleToProviderVec &subProviders )
 {
   if ( mSettings )
   {
-    QgsVectorLayerLabelProvider *p = subProviders[this];
-    if ( !p->prepare( context, attributeNames ) )
+    auto it = std::find_if( subProviders.begin(), subProviders.end(),
+                            [this]( const std::pair<QgsRuleBasedLabeling::Rule *, QgsVectorLayerLabelProvider *> &item )
     {
-      subProviders.remove( this );
-      delete p;
+      return item.first == this;
+    } );
+
+    if ( it != subProviders.end() )
+    {
+      QgsVectorLayerLabelProvider *p = it->second;
+      if ( !p->prepare( context, attributeNames ) )
+      {
+        subProviders.erase( it );
+        delete p;
+      }
     }
   }
 
@@ -354,7 +382,7 @@ void QgsRuleBasedLabeling::Rule::prepare( QgsRenderContext &context, QSet<QStrin
   }
 }
 
-std::tuple< QgsRuleBasedLabeling::Rule::RegisterResult, QList< QgsLabelFeature * > > QgsRuleBasedLabeling::Rule::registerFeature( const QgsFeature &feature, QgsRenderContext &context, QgsRuleBasedLabeling::RuleToProviderMap &subProviders, const QgsGeometry &obstacleGeometry, const QgsSymbol *symbol )
+std::tuple< QgsRuleBasedLabeling::Rule::RegisterResult, QList< QgsLabelFeature * > > QgsRuleBasedLabeling::Rule::registerFeature( const QgsFeature &feature, QgsRenderContext &context, QgsRuleBasedLabeling::RuleToProviderVec &subProviders, const QgsGeometry &obstacleGeometry, const QgsSymbol *symbol )
 {
   QList< QgsLabelFeature * > labels;
   if ( !isFilterOK( feature, context )
@@ -366,9 +394,15 @@ std::tuple< QgsRuleBasedLabeling::Rule::RegisterResult, QList< QgsLabelFeature *
   bool registered = false;
 
   // do we have active subprovider for the rule?
-  if ( subProviders.contains( this ) && mIsActive )
+  auto it = std::find_if( subProviders.begin(), subProviders.end(),
+                          [this]( const std::pair<QgsRuleBasedLabeling::Rule *, QgsVectorLayerLabelProvider *> &item )
   {
-    labels.append( subProviders[this]->registerFeature( feature, context, obstacleGeometry, symbol ) );
+    return item.first == this;
+  } );
+
+  if ( it != subProviders.end() && mIsActive )
+  {
+    labels.append( it->second->registerFeature( feature, context, obstacleGeometry, symbol ) );
     registered = true;
   }
 
@@ -609,4 +643,3 @@ void QgsRuleBasedLabeling::multiplyOpacity( double opacityFactor )
 
   }
 }
-
