@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgspointlocator.h"
+#include "moc_qgspointlocator.cpp"
 
 #include "qgsfeatureiterator.h"
 #include "qgsgeometry.h"
@@ -29,6 +30,7 @@
 #include "qgscurvepolygon.h"
 #include "qgsrendercontext.h"
 #include "qgspointlocatorinittask.h"
+#include "qgsspatialindexutils.h"
 #include <spatialindex/SpatialIndex.h>
 
 #include <QLinkedListIterator>
@@ -45,14 +47,6 @@ static SpatialIndex::Point point2point( const QgsPointXY &point )
 }
 
 
-static SpatialIndex::Region rect2region( const QgsRectangle &rect )
-{
-  double pLow[2] = { rect.xMinimum(), rect.yMinimum() };
-  double pHigh[2] = { rect.xMaximum(), rect.yMaximum() };
-  return SpatialIndex::Region( pLow, pHigh, 2 );
-}
-
-
 // Ahh.... another magic number. Taken from QgsVectorLayer::snapToGeometry() call to closestSegmentWithContext().
 // The default epsilon used for sqrDistToSegment (1e-8) is too high when working with lat/lon coordinates
 // I still do not fully understand why the sqrDistToSegment() code uses epsilon and if the square distance
@@ -1127,7 +1121,7 @@ bool QgsPointLocator::rebuildIndex( int maxFeaturesToIndex )
     const QgsRectangle bbox = f.geometry().boundingBox();
     if ( bbox.isFinite() )
     {
-      SpatialIndex::Region r( rect2region( bbox ) );
+      SpatialIndex::Region r( QgsSpatialIndexUtils::rectangleToRegion( bbox ) );
       dataList << new RTree::Data( 0, nullptr, r, f.id() );
 
       auto it = mGeoms.find( f.id() );
@@ -1261,7 +1255,7 @@ void QgsPointLocator::onFeatureAdded( QgsFeatureId fid )
     const QgsRectangle bbox = f.geometry().boundingBox();
     if ( bbox.isFinite() )
     {
-      const SpatialIndex::Region r( rect2region( bbox ) );
+      const SpatialIndex::Region r( QgsSpatialIndexUtils::rectangleToRegion( bbox ) );
       mRTree->insertData( 0, nullptr, r, f.id() );
 
       auto it = mGeoms.find( f.id() );
@@ -1300,7 +1294,7 @@ void QgsPointLocator::onFeatureDeleted( QgsFeatureId fid )
   auto it = mGeoms.find( fid );
   if ( it != mGeoms.end() )
   {
-    mRTree->deleteData( rect2region( ( *it )->boundingBox() ), fid );
+    mRTree->deleteData( QgsSpatialIndexUtils::rectangleToRegion( ( *it )->boundingBox() ), fid );
     delete *it;
     mGeoms.erase( it );
   }
@@ -1334,7 +1328,7 @@ QgsPointLocator::Match QgsPointLocator::nearestVertex( const QgsPointXY &point,
   Match m;
   QgsPointLocator_VisitorNearestVertex visitor( this, m, point, filter );
   const QgsRectangle rect( point.x() - tolerance, point.y() - tolerance, point.x() + tolerance, point.y() + tolerance );
-  mRTree->intersectsWithQuery( rect2region( rect ), visitor );
+  mRTree->intersectsWithQuery( QgsSpatialIndexUtils::rectangleToRegion( rect ), visitor );
   if ( m.isValid() && m.distance() > tolerance )
     return Match(); // make sure that only match strictly within the tolerance is returned
   return m;
@@ -1349,7 +1343,7 @@ QgsPointLocator::Match QgsPointLocator::nearestCentroid( const QgsPointXY &point
   QgsPointLocator_VisitorNearestCentroid visitor( this, m, point, filter );
 
   const QgsRectangle rect( point.x() - tolerance, point.y() - tolerance, point.x() + tolerance, point.y() + tolerance );
-  mRTree->intersectsWithQuery( rect2region( rect ), visitor );
+  mRTree->intersectsWithQuery( QgsSpatialIndexUtils::rectangleToRegion( rect ), visitor );
   if ( m.isValid() && m.distance() > tolerance )
     return Match(); // make sure that only match strictly within the tolerance is returned
   return m;
@@ -1364,7 +1358,7 @@ QgsPointLocator::Match QgsPointLocator::nearestMiddleOfSegment( const QgsPointXY
   QgsPointLocator_VisitorNearestMiddleOfSegment visitor( this, m, point, filter );
 
   const QgsRectangle rect( point.x() - tolerance, point.y() - tolerance, point.x() + tolerance, point.y() + tolerance );
-  mRTree->intersectsWithQuery( rect2region( rect ), visitor );
+  mRTree->intersectsWithQuery( QgsSpatialIndexUtils::rectangleToRegion( rect ), visitor );
   if ( m.isValid() && m.distance() > tolerance )
     return Match(); // make sure that only match strictly within the tolerance is returned
   return m;
@@ -1379,7 +1373,7 @@ QgsPointLocator::Match QgsPointLocator::nearestLineEndpoints( const QgsPointXY &
   QgsPointLocator_VisitorNearestLineEndpoint visitor( this, m, point, filter );
 
   const QgsRectangle rect( point.x() - tolerance, point.y() - tolerance, point.x() + tolerance, point.y() + tolerance );
-  mRTree->intersectsWithQuery( rect2region( rect ), visitor );
+  mRTree->intersectsWithQuery( QgsSpatialIndexUtils::rectangleToRegion( rect ), visitor );
   if ( m.isValid() && m.distance() > tolerance )
     return Match(); // make sure that only match strictly within the tolerance is returned
   return m;
@@ -1397,7 +1391,7 @@ QgsPointLocator::Match QgsPointLocator::nearestEdge( const QgsPointXY &point, do
   Match m;
   QgsPointLocator_VisitorNearestEdge visitor( this, m, point, filter );
   const QgsRectangle rect( point.x() - tolerance, point.y() - tolerance, point.x() + tolerance, point.y() + tolerance );
-  mRTree->intersectsWithQuery( rect2region( rect ), visitor );
+  mRTree->intersectsWithQuery( QgsSpatialIndexUtils::rectangleToRegion( rect ), visitor );
   if ( m.isValid() && m.distance() > tolerance )
     return Match(); // make sure that only match strictly within the tolerance is returned
   return m;
@@ -1444,7 +1438,7 @@ QgsPointLocator::MatchList QgsPointLocator::edgesInRect( const QgsRectangle &rec
 
   MatchList lst;
   QgsPointLocator_VisitorEdgesInRect visitor( this, lst, rect, filter );
-  mRTree->intersectsWithQuery( rect2region( rect ), visitor );
+  mRTree->intersectsWithQuery( QgsSpatialIndexUtils::rectangleToRegion( rect ), visitor );
 
   return lst;
 }
@@ -1462,7 +1456,7 @@ QgsPointLocator::MatchList QgsPointLocator::verticesInRect( const QgsRectangle &
 
   MatchList lst;
   QgsPointLocator_VisitorVerticesInRect visitor( this, lst, rect, filter );
-  mRTree->intersectsWithQuery( rect2region( rect ), visitor );
+  mRTree->intersectsWithQuery( QgsSpatialIndexUtils::rectangleToRegion( rect ), visitor );
 
   return lst;
 }
