@@ -87,6 +87,7 @@ bool QgsTextFormat::operator==( const QgsTextFormat &other ) const
        || d->forcedItalic != other.forcedItalic()
        || d->capitalization != other.capitalization()
        || d->tabStopDistance != other.tabStopDistance()
+       || d->tabPositions != other.tabPositions()
        || d->tabStopDistanceUnits != other.tabStopDistanceUnit()
        || d->tabStopDistanceMapUnitScale != other.tabStopDistanceMapUnitScale()
        || mBufferSettings != other.mBufferSettings
@@ -214,6 +215,7 @@ void QgsTextFormat::setFont( const QFont &font )
 {
   d->isValid = true;
   d->textFont = font;
+  d->originalFontFamily.clear();
 }
 
 QString QgsTextFormat::namedStyle() const
@@ -388,6 +390,17 @@ void QgsTextFormat::setTabStopDistance( double distance )
   d->tabStopDistance = distance;
 }
 
+QList<QgsTextFormat::Tab> QgsTextFormat::tabPositions() const
+{
+  return d->tabPositions;
+}
+
+void QgsTextFormat::setTabPositions( const QList<Tab> &positions )
+{
+  d->isValid = true;
+  d->tabPositions = positions;
+}
+
 Qgis::RenderUnit QgsTextFormat::tabStopDistanceUnit() const
 {
   return d->tabStopDistanceUnits;
@@ -466,7 +479,8 @@ void QgsTextFormat::readFromLayer( QgsVectorLayer *layer )
 {
   d->isValid = true;
   QFont appFont = QApplication::font();
-  mTextFontFamily = QgsApplication::fontManager()->processFontFamilyName( layer->customProperty( QStringLiteral( "labeling/fontFamily" ), QVariant( appFont.family() ) ).toString() );
+  d->originalFontFamily = QgsApplication::fontManager()->processFontFamilyName( layer->customProperty( QStringLiteral( "labeling/fontFamily" ), QVariant( appFont.family() ) ).toString() );
+  mTextFontFamily = d->originalFontFamily;
   QString fontFamily = mTextFontFamily;
   if ( mTextFontFamily != appFont.family() && !QgsFontUtils::fontFamilyMatchOnSystem( mTextFontFamily ) )
   {
@@ -555,7 +569,8 @@ void QgsTextFormat::readXml( const QDomElement &elem, const QgsReadWriteContext
   else
     textStyleElem = elem.firstChildElement( QStringLiteral( "text-style" ) );
   QFont appFont = QApplication::font();
-  mTextFontFamily = QgsApplication::fontManager()->processFontFamilyName( textStyleElem.attribute( QStringLiteral( "fontFamily" ), appFont.family() ) );
+  d->originalFontFamily = QgsApplication::fontManager()->processFontFamilyName( textStyleElem.attribute( QStringLiteral( "fontFamily" ), appFont.family() ) );
+  mTextFontFamily = d->originalFontFamily;
   QString fontFamily = mTextFontFamily;
 
   const QDomElement familiesElem = textStyleElem.firstChildElement( QStringLiteral( "families" ) );
@@ -661,7 +676,7 @@ void QgsTextFormat::readXml( const QDomElement &elem, const QgsReadWriteContext
   {
     d->opacity = ( textStyleElem.attribute( QStringLiteral( "textOpacity" ) ).toDouble() );
   }
-#ifdef HAS_KDE_QT5_FONT_STRETCH_FIX
+#if defined(HAS_KDE_QT5_FONT_STRETCH_FIX) || (QT_VERSION >= QT_VERSION_CHECK(6, 3, 0))
   d->textFont.setStretch( textStyleElem.attribute( QStringLiteral( "stretchFactor" ), QStringLiteral( "100" ) ).toInt() );
 #endif
   d->orientation = QgsTextRendererUtils::decodeTextOrientation( textStyleElem.attribute( QStringLiteral( "textOrientation" ) ) );
@@ -686,6 +701,19 @@ void QgsTextFormat::readXml( const QDomElement &elem, const QgsReadWriteContext
   d->tabStopDistanceUnits = QgsUnitTypes::decodeRenderUnit( textStyleElem.attribute( QStringLiteral( "tabStopDistanceUnit" ), QStringLiteral( "Point" ) ), &ok );
   d->tabStopDistanceMapUnitScale = QgsSymbolLayerUtils::decodeMapUnitScale( textStyleElem.attribute( QStringLiteral( "tabStopDistanceMapUnitScale" ) ) );
 
+  QList< Tab > tabPositions;
+  {
+    const QDomElement tabPositionsElem = textStyleElem.firstChildElement( QStringLiteral( "tabPositions" ) );
+    const QDomNodeList tabNodes = tabPositionsElem.childNodes();
+    tabPositions.reserve( tabNodes.size() );
+    for ( int i = 0; i < tabNodes.count(); ++i )
+    {
+      const QDomElement tabElem = tabNodes.at( i ).toElement();
+      tabPositions << Tab( tabElem.attribute( QStringLiteral( "position" ) ).toDouble() );
+    }
+  }
+  d->tabPositions = tabPositions;
+
   if ( textStyleElem.hasAttribute( QStringLiteral( "capitalization" ) ) )
     d->capitalization = static_cast< Qgis::Capitalization >( textStyleElem.attribute( QStringLiteral( "capitalization" ), QString::number( static_cast< int >( Qgis::Capitalization::MixedCase ) ) ).toInt() );
   else
@@ -749,7 +777,7 @@ QDomElement QgsTextFormat::writeXml( QDomDocument &doc, const QgsReadWriteContex
 {
   // text style
   QDomElement textStyleElem = doc.createElement( QStringLiteral( "text-style" ) );
-  textStyleElem.setAttribute( QStringLiteral( "fontFamily" ), d->textFont.family() );
+  textStyleElem.setAttribute( QStringLiteral( "fontFamily" ), !d->originalFontFamily.isEmpty() ? d->originalFontFamily : d->textFont.family() );
 
   QDomElement familiesElem = doc.createElement( QStringLiteral( "families" ) );
   for ( const QString &family : std::as_const( d->families ) )
@@ -776,7 +804,7 @@ QDomElement QgsTextFormat::writeXml( QDomDocument &doc, const QgsReadWriteContex
   textStyleElem.setAttribute( QStringLiteral( "fontWordSpacing" ), d->textFont.wordSpacing() );
   textStyleElem.setAttribute( QStringLiteral( "fontKerning" ), d->textFont.kerning() );
   textStyleElem.setAttribute( QStringLiteral( "textOpacity" ), d->opacity );
-#ifdef HAS_KDE_QT5_FONT_STRETCH_FIX
+#if defined(HAS_KDE_QT5_FONT_STRETCH_FIX) || (QT_VERSION >= QT_VERSION_CHECK(6, 3, 0))
   if ( d->textFont.stretch() > 0 )
     textStyleElem.setAttribute( QStringLiteral( "stretchFactor" ), d->textFont.stretch() );
 #endif
@@ -789,6 +817,18 @@ QDomElement QgsTextFormat::writeXml( QDomDocument &doc, const QgsReadWriteContex
   textStyleElem.setAttribute( QStringLiteral( "tabStopDistanceUnit" ), QgsUnitTypes::encodeUnit( d->tabStopDistanceUnits ) );
   textStyleElem.setAttribute( QStringLiteral( "tabStopDistanceMapUnitScale" ), QgsSymbolLayerUtils::encodeMapUnitScale( d->tabStopDistanceMapUnitScale ) );
 
+  if ( !d->tabPositions.empty() )
+  {
+    QDomElement tabPositionsElem = doc.createElement( QStringLiteral( "tabPositions" ) );
+    for ( const Tab &tab : std::as_const( d->tabPositions ) )
+    {
+      QDomElement tabElem = doc.createElement( QStringLiteral( "tab" ) );
+      tabElem.setAttribute( QStringLiteral( "position" ), tab.position() );
+      tabPositionsElem.appendChild( tabElem );
+    }
+    textStyleElem.appendChild( tabPositionsElem );
+  }
+
   textStyleElem.setAttribute( QStringLiteral( "allowHtml" ), d->allowHtmlFormatting ? QStringLiteral( "1" ) : QStringLiteral( "0" ) );
   textStyleElem.setAttribute( QStringLiteral( "capitalization" ), QString::number( static_cast< int >( d->capitalization ) ) );
 
@@ -1096,7 +1136,7 @@ void QgsTextFormat::updateDataDefinedProperties( QgsRenderContext &context )
     }
   }
 
-#ifdef HAS_KDE_QT5_FONT_STRETCH_FIX
+#if defined(HAS_KDE_QT5_FONT_STRETCH_FIX) || (QT_VERSION >= QT_VERSION_CHECK(6, 3, 0))
   if ( d->mDataDefinedProperties.isActive( QgsPalLayerSettings::Property::FontStretchFactor ) )
   {
     context.expressionContext().setOriginalValueVariable( d->textFont.stretch() );
@@ -1141,7 +1181,31 @@ void QgsTextFormat::updateDataDefinedProperties( QgsRenderContext &context )
     const QVariant val = d->mDataDefinedProperties.value( QgsPalLayerSettings::Property::TabStopDistance, context.expressionContext(), d->tabStopDistance );
     if ( !QgsVariantUtils::isNull( val ) )
     {
-      d->tabStopDistance = val.toDouble();
+      if ( val.userType() == QMetaType::Type::QVariantList )
+      {
+        const QVariantList parts = val.toList();
+        d->tabPositions.clear();
+        d->tabPositions.reserve( parts.size() );
+        for ( const QVariant &part : parts )
+        {
+          d->tabPositions.append( Tab( part.toDouble() ) );
+        }
+      }
+      else if ( val.userType() == QMetaType::Type::QStringList )
+      {
+        const QStringList parts = val.toStringList();
+        d->tabPositions.clear();
+        d->tabPositions.reserve( parts.size() );
+        for ( const QString &part : parts )
+        {
+          d->tabPositions.append( Tab( part.toDouble() ) );
+        }
+      }
+      else
+      {
+        d->tabPositions.clear();
+        d->tabStopDistance = val.toDouble();
+      }
     }
   }
 
@@ -1317,3 +1381,7 @@ QString QgsTextFormat::asCSS( double pointToPixelMultiplier ) const
 
   return css;
 }
+
+QgsTextFormat::Tab::Tab( double position )
+  : mPosition( position )
+{}
