@@ -16,6 +16,7 @@
 #include <QHBoxLayout>
 
 #include "qgsprojectionselectionwidget.h"
+#include "moc_qgsprojectionselectionwidget.cpp"
 #include "qgsapplication.h"
 #include "qgsprojectionselectiondialog.h"
 #include "qgsproject.h"
@@ -42,8 +43,7 @@ StandardCoordinateReferenceSystemsModel::StandardCoordinateReferenceSystemsModel
   const QgsSettings settings;
   mDefaultCrs = QgsCoordinateReferenceSystem( settings.value( QStringLiteral( "/projections/defaultProjectCrs" ), geoEpsgCrsAuthId(), QgsSettings::App ).toString() );
 
-  connect( QgsApplication::coordinateReferenceSystemRegistry(), &QgsCoordinateReferenceSystemRegistry::userCrsChanged, this, [ = ]
-  {
+  connect( QgsApplication::coordinateReferenceSystemRegistry(), &QgsCoordinateReferenceSystemRegistry::userCrsChanged, this, [=] {
     mCurrentCrs.updateDefinition();
     mLayerCrs.updateDefinition();
     mProjectCrs.updateDefinition();
@@ -94,7 +94,7 @@ QVariant StandardCoordinateReferenceSystemsModel::data( const QModelIndex &index
       return crs;
 
     case RoleOption:
-      return static_cast< int >( option );
+      return static_cast<int>( option );
 
     default:
       break;
@@ -274,7 +274,7 @@ bool CombinedCoordinateReferenceSystemsProxyModel::filterAcceptsRow( int sourceR
 {
   const QModelIndex sourceIndex = mModel->index( sourceRow, 0, sourceParent );
 
-  const QgsCoordinateReferenceSystem crs = mModel->data( sourceIndex, StandardCoordinateReferenceSystemsModel::RoleCrs ).value< QgsCoordinateReferenceSystem >();
+  const QgsCoordinateReferenceSystem crs = mModel->data( sourceIndex, StandardCoordinateReferenceSystemsModel::RoleCrs ).value<QgsCoordinateReferenceSystem>();
   if ( !mFilteredCrs.isEmpty() && !mFilteredCrs.contains( crs ) )
     return false;
 
@@ -313,7 +313,7 @@ bool CombinedCoordinateReferenceSystemsProxyModel::filterAcceptsRow( int sourceR
   {
     if ( optionInt.toInt() > 0 )
     {
-      const QgsProjectionSelectionWidget::CrsOption option = static_cast< QgsProjectionSelectionWidget::CrsOption >( optionInt.toInt() );
+      const QgsProjectionSelectionWidget::CrsOption option = static_cast<QgsProjectionSelectionWidget::CrsOption>( optionInt.toInt() );
       if ( !mVisibleOptions.testFlag( option ) )
         return false;
 
@@ -353,11 +353,11 @@ bool CombinedCoordinateReferenceSystemsProxyModel::filterAcceptsRow( int sourceR
             QgsProjectionSelectionWidget::CrsOption::ProjectCrs
           } )
     {
-      const QModelIndexList standardItemIndex = mModel->match( mModel->index( 0, 0 ), StandardCoordinateReferenceSystemsModel::RoleOption, static_cast< int >( standardOption ) );
+      const QModelIndexList standardItemIndex = mModel->match( mModel->index( 0, 0 ), StandardCoordinateReferenceSystemsModel::RoleOption, static_cast<int>( standardOption ) );
       if ( standardItemIndex.empty() )
         continue;
 
-      const QgsCoordinateReferenceSystem standardItemCrs = mModel->data( standardItemIndex.at( 0 ), StandardCoordinateReferenceSystemsModel::RoleCrs ).value< QgsCoordinateReferenceSystem >();
+      const QgsCoordinateReferenceSystem standardItemCrs = mModel->data( standardItemIndex.at( 0 ), StandardCoordinateReferenceSystemsModel::RoleCrs ).value<QgsCoordinateReferenceSystem>();
       if ( standardItemCrs == crs && filterAcceptsRow( standardItemIndex.at( 0 ).row(), QModelIndex() ) )
         return false;
     }
@@ -404,8 +404,7 @@ void CombinedCoordinateReferenceSystemsProxyModel::setOption( QgsProjectionSelec
 ///@endcond PRIVATE
 
 
-QgsProjectionSelectionWidget::QgsProjectionSelectionWidget( QWidget *parent,
-    QgsCoordinateReferenceSystemProxyModel::Filters filters )
+QgsProjectionSelectionWidget::QgsProjectionSelectionWidget( QWidget *parent, QgsCoordinateReferenceSystemProxyModel::Filters filters )
   : QWidget( parent )
   , mDialogTitle( tr( "Coordinate Reference System Selector" ) )
 {
@@ -416,7 +415,7 @@ QgsProjectionSelectionWidget::QgsProjectionSelectionWidget( QWidget *parent,
   mModel->setFilters( filters );
   mCrsComboBox->setModel( mModel );
 
-  const int labelMargin = static_cast< int >( std::round( mCrsComboBox->fontMetrics().horizontalAdvance( 'X' ) ) );
+  const int labelMargin = static_cast<int>( std::round( mCrsComboBox->fontMetrics().horizontalAdvance( 'X' ) ) );
   QHBoxLayout *layout = new QHBoxLayout();
   layout->setContentsMargins( 0, 0, 0, 0 );
   layout->setSpacing( 0 );
@@ -432,7 +431,7 @@ QgsProjectionSelectionWidget::QgsProjectionSelectionWidget( QWidget *parent,
   warningLayout->setContentsMargins( 0, 0, 0, 0 );
   mWarningLabel = new QLabel();
   const QIcon icon = QgsApplication::getThemeIcon( QStringLiteral( "mIconWarning.svg" ) );
-  const int size = static_cast< int >( std::max( 24.0, mCrsComboBox->minimumSize().height() * 0.5 ) );
+  const int size = static_cast<int>( std::max( 24.0, mCrsComboBox->minimumSize().height() * 0.5 ) );
   mWarningLabel->setPixmap( icon.pixmap( icon.actualSize( QSize( size, size ) ) ) );
   warningLayout->insertSpacing( 0, labelMargin / 2 );
   warningLayout->insertWidget( 1, mWarningLabel );
@@ -459,7 +458,7 @@ QgsCoordinateReferenceSystem QgsProjectionSelectionWidget::crs() const
 {
   const int idx = mCrsComboBox->currentIndex();
   if ( idx >= 0 && idx < mModel->rowCount() )
-    return mModel->data( mModel->index( idx, 0 ), StandardCoordinateReferenceSystemsModel::RoleCrs ).value< QgsCoordinateReferenceSystem >();
+    return mModel->data( mModel->index( idx, 0 ), StandardCoordinateReferenceSystemsModel::RoleCrs ).value<QgsCoordinateReferenceSystem>();
   else
     return QgsCoordinateReferenceSystem();
 }
@@ -514,17 +513,17 @@ void QgsProjectionSelectionWidget::setMessage( const QString &text )
 
 bool QgsProjectionSelectionWidget::optionVisible( QgsProjectionSelectionWidget::CrsOption option ) const
 {
-  const QModelIndexList matches = mModel->match( mModel->index( 0, 0 ), StandardCoordinateReferenceSystemsModel::Role::RoleOption, static_cast< int >( option ) );
+  const QModelIndexList matches = mModel->match( mModel->index( 0, 0 ), StandardCoordinateReferenceSystemsModel::Role::RoleOption, static_cast<int>( option ) );
   return !matches.empty();
 }
 
 void QgsProjectionSelectionWidget::selectCrs()
 {
   QgsPanelWidget *panel = QgsPanelWidget::findParentPanel( this );
-  const QList< QgsCoordinateReferenceSystem > filteredCrses = mModel->filteredCrs();
+  const QList<QgsCoordinateReferenceSystem> filteredCrses = mModel->filteredCrs();
 
-  QSet< QString > ogcFilter;
-  ogcFilter.reserve( filteredCrses.size( ) );
+  QSet<QString> ogcFilter;
+  ogcFilter.reserve( filteredCrses.size() );
   for ( const QgsCoordinateReferenceSystem &crs : std::as_const( filteredCrses ) )
   {
     ogcFilter << crs.authid();
@@ -549,8 +548,7 @@ void QgsProjectionSelectionWidget::selectCrs()
       mActivePanel->setShowNoCrs( true );
     }
 
-    connect( mActivePanel, &QgsCrsSelectionWidget::crsChanged, this, [ this ]
-    {
+    connect( mActivePanel, &QgsCrsSelectionWidget::crsChanged, this, [this] {
       if ( mIgnorePanelSignals )
         return;
 
@@ -726,9 +724,9 @@ void QgsProjectionSelectionWidget::comboIndexChanged( int idx )
 {
   if ( idx >= 0 && idx < mModel->rowCount() )
   {
-    const QgsCoordinateReferenceSystem crs = mModel->data( mModel->index( idx, 0 ), StandardCoordinateReferenceSystemsModel::RoleCrs ).value< QgsCoordinateReferenceSystem >();
+    const QgsCoordinateReferenceSystem crs = mModel->data( mModel->index( idx, 0 ), StandardCoordinateReferenceSystemsModel::RoleCrs ).value<QgsCoordinateReferenceSystem>();
     const QVariant optionData = mModel->data( mModel->index( idx, 0 ), StandardCoordinateReferenceSystemsModel::RoleOption );
-    if ( !optionData.isValid() || static_cast< CrsOption >( optionData.toInt() ) != QgsProjectionSelectionWidget::CrsNotSet )
+    if ( !optionData.isValid() || static_cast<CrsOption>( optionData.toInt() ) != QgsProjectionSelectionWidget::CrsNotSet )
     {
       // RoleOption is only available for items from the standard coordinate reference system model, but we
       // are using a combined model which also has items from QgsRecentCoordinateReferenceSystemsModel
@@ -784,7 +782,7 @@ void QgsProjectionSelectionWidget::updateWarning()
       }
       warning += QStringLiteral( "</p><p>" ) + tr( "Use an alternative CRS if accurate positioning is required." ) + QStringLiteral( "</p>" );
 
-      const QList< QgsDatumEnsembleMember > members = ensemble.members();
+      const QList<QgsDatumEnsembleMember> members = ensemble.members();
       if ( !members.isEmpty() )
       {
         warning += QStringLiteral( "<p>" ) + tr( "%1 consists of the datums:" ).arg( ensemble.name() ) + QStringLiteral( "</p><ul>" );
