@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgsoracleconn.h"
+#include "moc_qgsoracleconn.cpp"
 #include "qgslogger.h"
 #include "qgsdatasourceuri.h"
 #include "qgsmessagelog.h"
@@ -65,7 +66,7 @@ QgsOracleConn *QgsOracleConn::connectDb( const QgsDataSourceUri &uri, bool trans
   return conn;
 }
 
-QgsOracleConn::QgsOracleConn( QgsDataSourceUri uri, bool transaction )
+QgsOracleConn::QgsOracleConn( const QgsDataSourceUri &uri, bool transaction )
   : mRef( 1 )
   , mCurrentUser( QString() )
   , mHasSpatial( -1 )
@@ -77,28 +78,28 @@ QgsOracleConn::QgsOracleConn( QgsDataSourceUri uri, bool transaction )
   // so we don't want login/password here
   mConnInfo = uri.connectionInfo( false );
 
-  uri = QgsDataSourceUri( uri.connectionInfo( true ) );
+  QgsDataSourceUri expandedUri = QgsDataSourceUri( uri.connectionInfo( true ) );
 
-  QString database = databaseName( uri.database(), uri.host(), uri.port() );
+  QString database = databaseName( expandedUri.database(), expandedUri.host(), expandedUri.port() );
   QgsDebugMsgLevel( QStringLiteral( "New Oracle database " ) + database, 2 );
 
   mDatabase = QSqlDatabase::addDatabase( QStringLiteral( "QOCISPATIAL" ), QStringLiteral( "oracle%1" ).arg( snConnections++ ) );
   mDatabase.setDatabaseName( database );
-  QString options = uri.hasParam( QStringLiteral( "dboptions" ) ) ? uri.param( QStringLiteral( "dboptions" ) ) : QStringLiteral( "OCI_ATTR_PREFETCH_ROWS=1000" );
+  QString options = expandedUri.hasParam( QStringLiteral( "dboptions" ) ) ? expandedUri.param( QStringLiteral( "dboptions" ) ) : QStringLiteral( "OCI_ATTR_PREFETCH_ROWS=1000" );
   if ( mTransaction )
     options += ( !options.isEmpty() ? QStringLiteral( ";" ) : QString() ) + QStringLiteral( "COMMIT_ON_SUCCESS=false" );
-  QString workspace = uri.hasParam( QStringLiteral( "dbworkspace" ) ) ? uri.param( QStringLiteral( "dbworkspace" ) ) : QString();
+  QString workspace = expandedUri.hasParam( QStringLiteral( "dbworkspace" ) ) ? expandedUri.param( QStringLiteral( "dbworkspace" ) ) : QString();
   mDatabase.setConnectOptions( options );
-  mDatabase.setUserName( uri.username() );
-  mDatabase.setPassword( uri.password() );
+  mDatabase.setUserName( expandedUri.username() );
+  mDatabase.setPassword( expandedUri.password() );
 
-  QString username = uri.username();
-  QString password = uri.password();
+  QString username = expandedUri.username();
+  QString password = expandedUri.password();
 
   if ( sBrokenConnections.contains( mConnInfo ) )
   {
     QDateTime now( QDateTime::currentDateTime() );
-    QDateTime since( sBrokenConnections[ mConnInfo ] );
+    QDateTime since( sBrokenConnections[mConnInfo] );
     QgsDebugError( QStringLiteral( "Broken since %1 [%2s ago]" ).arg( since.toString( Qt::ISODate ) ).arg( since.secsTo( now ) ) );
 
     if ( since.secsTo( now ) < 30 )
@@ -129,11 +130,11 @@ QgsOracleConn::QgsOracleConn( QgsDataSourceUri uri, bool transaction )
 
       if ( !username.isEmpty() )
       {
-        uri.setUsername( username );
+        expandedUri.setUsername( username );
       }
 
       if ( !password.isEmpty() )
-        uri.setPassword( password );
+        expandedUri.setPassword( password );
 
       QgsDebugMsgLevel( "Connecting to " + database, 2 );
       mDatabase.setUserName( username );
@@ -155,8 +156,7 @@ QgsOracleConn::QgsOracleConn( QgsDataSourceUri uri, bool transaction )
   }
 
   QSqlQuery qry( mDatabase );
-  if ( !LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, QStringLiteral( "alter session set nls_date_format = 'yyyy-mm-dd\"T\"HH24:MI:ss'" ),
-                           QVariantList() ) )
+  if ( !LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, QStringLiteral( "alter session set nls_date_format = 'yyyy-mm-dd\"T\"HH24:MI:ss'" ), QVariantList() ) )
   {
     mDatabase.close();
     const QString error { tr( "Error: Failed to switch the default format date to ISO" ) };
@@ -241,10 +241,10 @@ QString QgsOracleConn::getLastExecutedQuery( const QSqlQuery &query )
   for ( QVariant value : query.boundValues() )
   {
     const QVariant &var { value.toString() };
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QSqlField field( QString( ), var.type() );
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
+    QSqlField field( QString(), var.type() );
 #else
-    QSqlField field( QString( ), var.metaType() );
+    QSqlField field( QString(), var.metaType() );
 #endif
 
     if ( var.isNull() )
@@ -282,12 +282,10 @@ bool QgsOracleConn::exec( QSqlQuery &qry, const QString &sql, const QVariantList
   if ( !res )
   {
     QgsDebugError( QStringLiteral( "SQL: %1\nERROR: %2" )
-                   .arg( qry.lastQuery(),
-                         qry.lastError().text() ) );
+                     .arg( qry.lastQuery(), qry.lastError().text() ) );
   }
 
   return res;
-
 }
 
 bool QgsOracleConn::execLogged( QSqlQuery &qry, const QString &sql, const QVariantList &params, const QString &originatorClass, const QString &queryOrigin )
@@ -314,8 +312,7 @@ bool QgsOracleConn::execLogged( QSqlQuery &qry, const QString &sql, const QVaria
   {
     logWrapper.setError( qry.lastError().text() );
     QgsDebugError( QStringLiteral( "SQL: %1\nERROR: %2" )
-                   .arg( qry.lastQuery(),
-                         qry.lastError().text() ) );
+                     .arg( qry.lastQuery(), qry.lastError().text() ) );
   }
   else
   {
@@ -338,8 +335,7 @@ QStringList QgsOracleConn::pkCandidates( const QString &ownerName, const QString
 
   QSqlQuery qry( mDatabase );
 
-  if ( !LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, QStringLiteral( "SELECT column_name FROM all_tab_columns WHERE owner=? AND table_name=? ORDER BY column_id" ),
-                           QVariantList() << ownerName << viewName ) )
+  if ( !LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, QStringLiteral( "SELECT column_name FROM all_tab_columns WHERE owner=? AND table_name=? ORDER BY column_id" ), QVariantList() << ownerName << viewName ) )
   {
     const QString error { tr( "SQL: %1 [owner: %2 table_name: %3]\nerror: %4\n" ).arg( qry.lastQuery(), qry.lastError().text(), ownerName, viewName ) };
     QgsMessageLog::logMessage( error, tr( "Oracle" ) );
@@ -365,17 +361,12 @@ bool QgsOracleConn::tableInfo( const QString &schema, bool geometryColumnsOnly,
   QString sql;
 
   QString prefix( userTablesOnly ? QStringLiteral( "user" ) : QStringLiteral( "all" ) ),
-          owner( userTablesOnly ? QStringLiteral( "user AS owner" ) : QStringLiteral( "c.owner" ) );
+    owner( userTablesOnly ? QStringLiteral( "user AS owner" ) : QStringLiteral( "c.owner" ) );
 
   sql = QStringLiteral( "SELECT %1,c.table_name,c.column_name,%2,o.object_type AS type"
                         " FROM %3_%4 c"
                         " JOIN %3_objects o ON c.table_name=o.object_name AND o.object_type IN ('TABLE','VIEW','SYNONYM')%5%6" )
-        .arg( owner,
-              geometryColumnsOnly ? QStringLiteral( "c.srid" ) : QStringLiteral( "NULL AS srid" ),
-              prefix,
-              geometryColumnsOnly ? QStringLiteral( "sdo_geom_metadata" ) : QStringLiteral( "tab_columns" ),
-              userTablesOnly ? QString() : QStringLiteral( " AND c.owner=%1" ).arg( schema.isEmpty() ? QStringLiteral( "o.owner" ) : quotedValue( schema ) ),
-              geometryColumnsOnly ? QString() : QStringLiteral( " WHERE c.data_type='SDO_GEOMETRY'" ) );
+          .arg( owner, geometryColumnsOnly ? QStringLiteral( "c.srid" ) : QStringLiteral( "NULL AS srid" ), prefix, geometryColumnsOnly ? QStringLiteral( "sdo_geom_metadata" ) : QStringLiteral( "tab_columns" ), userTablesOnly ? QString() : QStringLiteral( " AND c.owner=%1" ).arg( schema.isEmpty() ? QStringLiteral( "o.owner" ) : quotedValue( schema ) ), geometryColumnsOnly ? QString() : QStringLiteral( " WHERE c.data_type='SDO_GEOMETRY'" ) );
 
   if ( allowGeometrylessTables )
   {
@@ -384,9 +375,7 @@ bool QgsOracleConn::tableInfo( const QString &schema, bool geometryColumnsOnly,
                            " FROM %2_objects c WHERE c.object_type IN ('TABLE','VIEW','SYNONYM') "
                            // get only geometry table without geometry column
                            " AND NOT EXISTS( SELECT 1 FROM %2_tab_columns cols WHERE cols.table_name=c.object_name AND cols.data_type='SDO_GEOMETRY') %3" )
-           .arg( owner,
-                 prefix,
-                 userTablesOnly || schema.isEmpty() ? QString() : QStringLiteral( " AND c.owner=%1" ).arg( quotedValue( schema ) ) );
+             .arg( owner, prefix, userTablesOnly || schema.isEmpty() ? QString() : QStringLiteral( " AND c.owner=%1" ).arg( quotedValue( schema ) ) );
   }
 
   QSqlQuery qry( mDatabase );
@@ -401,16 +390,15 @@ bool QgsOracleConn::tableInfo( const QString &schema, bool geometryColumnsOnly,
   while ( qry.next() )
   {
     QgsOracleLayerProperty layerProperty;
-    layerProperty.ownerName       = qry.value( 0 ).toString();
-    layerProperty.tableName       = qry.value( 1 ).toString();
+    layerProperty.ownerName = qry.value( 0 ).toString();
+    layerProperty.tableName = qry.value( 1 ).toString();
     layerProperty.geometryColName = qry.value( 2 ).toString();
-    layerProperty.types           = QList<Qgis::WkbType>() << ( qry.value( 2 ).isNull() ? Qgis::WkbType::NoGeometry : Qgis::WkbType::Unknown );
-    layerProperty.srids           = QList<int>() << qry.value( 3 ).toInt();
-    layerProperty.isView          = qry.value( 4 ) != QLatin1String( "TABLE" );
+    layerProperty.types = QList<Qgis::WkbType>() << ( qry.value( 2 ).isNull() ? Qgis::WkbType::NoGeometry : Qgis::WkbType::Unknown );
+    layerProperty.srids = QList<int>() << qry.value( 3 ).toInt();
+    layerProperty.isView = qry.value( 4 ) != QLatin1String( "TABLE" );
     layerProperty.pkCols.clear();
 
     mLayersSupported << layerProperty;
-
   }
 
 
@@ -510,14 +498,13 @@ bool QgsOracleConn::exec( const QString &query, bool logError, QString *errorMes
     if ( logError )
     {
       const QString errorMsg { tr( "Connection error: %1 returned %2" )
-                               .arg( query, error ) };
-      QgsMessageLog::logMessage( errorMsg,
-                                 tr( "Oracle" ) );
+                                 .arg( query, error ) };
+      QgsMessageLog::logMessage( errorMsg, tr( "Oracle" ) );
     }
     else
     {
       const QString errorMsg { QStringLiteral( "Connection error: %1 returned %2" )
-                               .arg( query, error ) };
+                                 .arg( query, error ) };
       QgsDebugError( errorMsg );
     }
     if ( errorMessage )
@@ -529,7 +516,6 @@ bool QgsOracleConn::exec( const QString &query, bool logError, QString *errorMes
 
 bool QgsOracleConn::execLogged( const QString &query, bool logError, QString *errorMessage, const QString &originatorClass, const QString &queryOrigin )
 {
-
   QMutexLocker locker( &mLock );
   QgsDatabaseQueryLogWrapper logWrapper { query, mConnInfo, QStringLiteral( "oracle" ), originatorClass, queryOrigin };
 
@@ -541,21 +527,20 @@ bool QgsOracleConn::execLogged( const QString &query, bool logError, QString *er
 
   logWrapper.setQuery( qry.lastQuery() );
 
-  if ( ! res )
+  if ( !res )
   {
     const QString error = qry.lastError().text();
     logWrapper.setError( error );
     if ( logError )
     {
       const QString errorMsg { tr( "Connection error: %1 returned %2" )
-                               .arg( query, error ) };
-      QgsMessageLog::logMessage( errorMsg,
-                                 tr( "Oracle" ) );
+                                 .arg( query, error ) };
+      QgsMessageLog::logMessage( errorMsg, tr( "Oracle" ) );
     }
     else
     {
       const QString errorMsg { QStringLiteral( "Connection error: %1 returned %2" )
-                               .arg( query, error ) };
+                                 .arg( query, error ) };
       QgsDebugError( errorMsg );
     }
     if ( errorMessage )
@@ -661,9 +646,7 @@ void QgsOracleConn::retrieveLayerTypes( QgsOracleLayerProperty &layerProperty, b
     layerProperty.pkCols = pkCandidates( layerProperty.ownerName, layerProperty.tableName );
     if ( layerProperty.pkCols.isEmpty() )
     {
-      QgsMessageLog::logMessage( tr( "View %1.%2 doesn't have integer columns for use as keys." )
-                                 .arg( layerProperty.ownerName, layerProperty.tableName ),
-                                 tr( "Oracle" ) );
+      QgsMessageLog::logMessage( tr( "View %1.%2 doesn't have integer columns for use as keys." ).arg( layerProperty.ownerName, layerProperty.tableName ), tr( "Oracle" ) );
     }
   }
 
@@ -676,17 +659,13 @@ void QgsOracleConn::retrieveLayerTypes( QgsOracleLayerProperty &layerProperty, b
   if ( useEstimatedMetadata )
   {
     table = QStringLiteral( "(SELECT %1 FROM %2.%3 WHERE %1 IS NOT NULL%4 AND rownum<=%5)" )
-            .arg( quotedIdentifier( layerProperty.geometryColName ),
-                  quotedIdentifier( layerProperty.ownerName ),
-                  quotedIdentifier( layerProperty.tableName ),
-                  layerProperty.sql.isEmpty() ? QString() : QStringLiteral( " AND (%1)" ).arg( layerProperty.sql ) )
-            .arg( sGeomTypeSelectLimit );
+              .arg( quotedIdentifier( layerProperty.geometryColName ), quotedIdentifier( layerProperty.ownerName ), quotedIdentifier( layerProperty.tableName ), layerProperty.sql.isEmpty() ? QString() : QStringLiteral( " AND (%1)" ).arg( layerProperty.sql ) )
+              .arg( sGeomTypeSelectLimit );
   }
   else if ( !layerProperty.ownerName.isEmpty() )
   {
     table = QStringLiteral( "%1.%2" )
-            .arg( quotedIdentifier( layerProperty.ownerName ),
-                  quotedIdentifier( layerProperty.tableName ) );
+              .arg( quotedIdentifier( layerProperty.ownerName ), quotedIdentifier( layerProperty.tableName ) );
     where = layerProperty.sql;
   }
   else
@@ -720,16 +699,11 @@ void QgsOracleConn::retrieveLayerTypes( QgsOracleLayerProperty &layerProperty, b
 
   sql += QLatin1String( " FROM %2 t WHERE NOT t.%1 IS NULL%3" );
 
-  if ( !LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, sql
-                           .arg( quotedIdentifier( layerProperty.geometryColName ),
-                                 table,
-                                 where.isEmpty() ? QString() : QStringLiteral( " AND (%1)" ).arg( where ) ), QVariantList() ) )
+  if ( !LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, sql.arg( quotedIdentifier( layerProperty.geometryColName ), table, where.isEmpty() ? QString() : QStringLiteral( " AND (%1)" ).arg( where ) ), QVariantList() ) )
   {
     const QString error { tr( "SQL: %1\nerror: %2\n" )
-                          .arg( qry.lastQuery(),
-                                qry.lastError().text() ) };
-    QgsMessageLog::logMessage( error,
-                               tr( "Oracle" ) );
+                            .arg( qry.lastQuery(), qry.lastError().text() ) };
+    QgsMessageLog::logMessage( error, tr( "Oracle" ) );
     return;
   }
 
@@ -744,10 +718,7 @@ void QgsOracleConn::retrieveLayerTypes( QgsOracleLayerProperty &layerProperty, b
       Qgis::WkbType type = wkbTypeFromDatabase( qry.value( 0 ).toInt() );
       if ( type == Qgis::WkbType::Unknown )
       {
-        QgsMessageLog::logMessage( tr( "Unsupported geometry type %1 in %2.%3.%4 ignored" )
-                                   .arg( qry.value( 0 ).toInt() )
-                                   .arg( layerProperty.ownerName, layerProperty.tableName,  layerProperty.geometryColName ),
-                                   tr( "Oracle" ) );
+        QgsMessageLog::logMessage( tr( "Unsupported geometry type %1 in %2.%3.%4 ignored" ).arg( qry.value( 0 ).toInt() ).arg( layerProperty.ownerName, layerProperty.tableName, layerProperty.geometryColName ), tr( "Oracle" ) );
         continue;
       }
       QgsDebugMsgLevel( QStringLiteral( "add type %1" ).arg( qgsEnumValueToKey( type ) ), 2 );
@@ -1125,8 +1096,8 @@ int QgsOracleConn::version()
   else
   {
     const QString error { tr( "Unable to execute the query.\nThe error message from the database was:\n%1.\nSQL: %2" )
-                          .arg( qry.lastError().text() )
-                          .arg( qry.lastQuery() ) };
+                            .arg( qry.lastError().text() )
+                            .arg( qry.lastQuery() ) };
     QgsMessageLog::logMessage( error, tr( "Oracle" ) );
     return -1;
   }
@@ -1179,9 +1150,9 @@ QString QgsOracleConn::getSpatialIndexName( const QString &ownerName, const QStr
   QSqlQuery qry( mDatabase );
 
   if ( LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, QStringLiteral( "SELECT i.index_name,i.domidx_opstatus"
-                          " FROM all_indexes i"
-                          " JOIN all_ind_columns c ON i.owner=c.index_owner AND i.index_name=c.index_name AND c.column_name=?"
-                          " WHERE i.table_owner=? AND i.table_name=? AND i.ityp_owner='MDSYS' AND i.ityp_name='SPATIAL_INDEX'" ),
+                                                                                  " FROM all_indexes i"
+                                                                                  " JOIN all_ind_columns c ON i.owner=c.index_owner AND i.index_name=c.index_name AND c.column_name=?"
+                                                                                  " WHERE i.table_owner=? AND i.table_name=? AND i.ityp_owner='MDSYS' AND i.ityp_name='SPATIAL_INDEX'" ),
                           QVariantList() << geometryColumn << ownerName << tableName ) )
   {
     if ( qry.next() )
@@ -1189,12 +1160,7 @@ QString QgsOracleConn::getSpatialIndexName( const QString &ownerName, const QStr
       name = qry.value( 0 ).toString();
       if ( qry.value( 1 ).toString() != "VALID" )
       {
-        QgsMessageLog::logMessage( tr( "Invalid spatial index %1 on column %2.%3.%4 found - expect poor performance." )
-                                   .arg( name )
-                                   .arg( ownerName )
-                                   .arg( tableName )
-                                   .arg( geometryColumn ),
-                                   tr( "Oracle" ) );
+        QgsMessageLog::logMessage( tr( "Invalid spatial index %1 on column %2.%3.%4 found - expect poor performance." ).arg( name ).arg( ownerName ).arg( tableName ).arg( geometryColumn ), tr( "Oracle" ) );
         isValid = false;
       }
       else
@@ -1211,12 +1177,11 @@ QString QgsOracleConn::getSpatialIndexName( const QString &ownerName, const QStr
   else
   {
     const QString error { tr( "Probing for spatial index on column %1.%2.%3 failed [%4]" )
-                          .arg( ownerName )
-                          .arg( tableName )
-                          .arg( geometryColumn )
-                          .arg( qry.lastError().text() ) };
-    QgsMessageLog::logMessage( error,
-                               tr( "Oracle" ) );
+                            .arg( ownerName )
+                            .arg( tableName )
+                            .arg( geometryColumn )
+                            .arg( qry.lastError().text() ) };
+    QgsMessageLog::logMessage( error, tr( "Oracle" ) );
 
     isValid = false;
   }
@@ -1231,24 +1196,22 @@ QString QgsOracleConn::createSpatialIndex( const QString &ownerName, const QStri
   int n = 0;
   const QString sql { QStringLiteral( "SELECT coalesce(substr(max(index_name),10),'0') FROM all_indexes WHERE index_name LIKE 'QGIS_IDX_%' ESCAPE '#' ORDER BY index_name" ) };
 
-  if ( LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, sql, QVariantList() ) &&
-       qry.next() )
+  if ( LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, sql, QVariantList() ) && qry.next() )
   {
     n = qry.value( 0 ).toInt() + 1;
   }
 
   const QString sql2 { QStringLiteral( "CREATE INDEX QGIS_IDX_%1 ON %2.%3(%4) INDEXTYPE IS MDSYS.SPATIAL_INDEX PARALLEL" )
-                       .arg( n, 10, 10, QChar( '0' ) )
-                       .arg( quotedIdentifier( ownerName ) )
-                       .arg( quotedIdentifier( tableName ) )
-                       .arg( quotedIdentifier( geometryColumn ) ) };
+                         .arg( n, 10, 10, QChar( '0' ) )
+                         .arg( quotedIdentifier( ownerName ) )
+                         .arg( quotedIdentifier( tableName ) )
+                         .arg( quotedIdentifier( geometryColumn ) ) };
   if ( !LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, sql2, QVariantList() ) )
   {
     const QString error { tr( "Creation spatial index failed.\nSQL: %1\nError: %2" )
-                          .arg( qry.lastQuery() )
-                          .arg( qry.lastError().text() ) };
-    QgsMessageLog::logMessage( error,
-                               tr( "Oracle" ) );
+                            .arg( qry.lastQuery() )
+                            .arg( qry.lastError().text() ) };
+    QgsMessageLog::logMessage( error, tr( "Oracle" ) );
     return QString();
   }
 
@@ -1262,14 +1225,14 @@ QStringList QgsOracleConn::getPrimaryKeys( const QString &ownerName, const QStri
   QStringList result;
 
   if ( !LoggedExecPrivate( QStringLiteral( "QgsOracleConn" ), qry, QStringLiteral( "SELECT column_name"
-                           " FROM all_cons_columns a"
-                           " JOIN all_constraints b ON a.constraint_name=b.constraint_name AND a.owner=b.owner"
-                           " WHERE b.constraint_type='P' AND b.owner=? AND b.table_name=?" ),
+                                                                                   " FROM all_cons_columns a"
+                                                                                   " JOIN all_constraints b ON a.constraint_name=b.constraint_name AND a.owner=b.owner"
+                                                                                   " WHERE b.constraint_type='P' AND b.owner=? AND b.table_name=?" ),
                            QVariantList() << ownerName << tableName ) )
   {
     const QString error { tr( "Unable to execute the query.\nThe error message from the database was:\n%1.\nSQL: %2" )
-                          .arg( qry.lastError().text() )
-                          .arg( qry.lastQuery() ) };
+                            .arg( qry.lastError().text() )
+                            .arg( qry.lastQuery() ) };
     QgsMessageLog::logMessage( error, tr( "Oracle" ) );
     return result;
   }
