@@ -23,9 +23,7 @@
 
 class TestGeospatialPdfExporter : public QgsAbstractGeospatialPdfExporter
 {
-
   private:
-
     VectorComponentDetail componentDetailForLayerId( const QString &layerId ) override
     {
       Q_UNUSED( layerId );
@@ -35,7 +33,6 @@ class TestGeospatialPdfExporter : public QgsAbstractGeospatialPdfExporter
       detail.displayAttribute = QStringLiteral( "attr %1" ).arg( layerId );
       return detail;
     }
-
 };
 
 class TestQgsGeospatialPdfExport : public QgsTest
@@ -43,11 +40,12 @@ class TestQgsGeospatialPdfExport : public QgsTest
     Q_OBJECT
 
   public:
-    TestQgsGeospatialPdfExport() : QgsTest( QStringLiteral( "Geospatial PDF Export Testss" ) ) {}
+    TestQgsGeospatialPdfExport()
+      : QgsTest( QStringLiteral( "Geospatial PDF Export Testss" ) ) {}
 
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
-    void cleanupTestCase();// will be called after the last testfunction was executed.
+    void initTestCase();    // will be called before the first testfunction is executed.
+    void cleanupTestCase(); // will be called after the last testfunction was executed.
     void testCollectingFeatures();
     void testComposition();
     void testMetadata();
@@ -116,7 +114,7 @@ void TestQgsGeospatialPdfExport::testCollectingFeatures()
   QCOMPARE( component.mapLayerId, QStringLiteral( "layer1" ) );
   QCOMPARE( component.name, QStringLiteral( "name layer1" ) );
   // check that temporary layers were correctly written
-  std::unique_ptr< QgsVectorLayer > layer = std::make_unique< QgsVectorLayer >( QStringLiteral( "%1|layerName=%2" ).arg( component.sourceVectorPath, component.sourceVectorLayer ), QStringLiteral( "layer" ), QStringLiteral( "ogr" ) );
+  auto layer = std::make_unique<QgsVectorLayer>( QStringLiteral( "%1|layerName=%2" ).arg( component.sourceVectorPath, component.sourceVectorLayer ), QStringLiteral( "layer" ), QStringLiteral( "ogr" ) );
   QVERIFY( layer->isValid() );
   QCOMPARE( layer->featureCount(), 2L );
   QCOMPARE( layer->wkbType(), Qgis::WkbType::Polygon );
@@ -142,7 +140,7 @@ void TestQgsGeospatialPdfExport::testCollectingFeatures()
   }
   QCOMPARE( component.mapLayerId, QStringLiteral( "layer2" ) );
   QCOMPARE( component.name, QStringLiteral( "name layer2" ) );
-  layer = std::make_unique< QgsVectorLayer >( QStringLiteral( "%1|layerName=%2" ).arg( component.sourceVectorPath, component.sourceVectorLayer ), QStringLiteral( "layer" ), QStringLiteral( "ogr" ) );
+  layer = std::make_unique<QgsVectorLayer>( QStringLiteral( "%1|layerName=%2" ).arg( component.sourceVectorPath, component.sourceVectorLayer ), QStringLiteral( "layer" ), QStringLiteral( "ogr" ) );
   QVERIFY( layer->isValid() );
   QCOMPARE( layer->featureCount(), 1L );
   QCOMPARE( layer->wkbType(), Qgis::WkbType::LineString );
@@ -198,7 +196,7 @@ void TestQgsGeospatialPdfExport::testComposition()
   }
 
   // test creation of the composition xml
-  QList< QgsAbstractGeospatialPdfExporter::ComponentLayerDetail > renderedLayers;
+  QList<QgsAbstractGeospatialPdfExporter::ComponentLayerDetail> renderedLayers;
   QgsAbstractGeospatialPdfExporter::ComponentLayerDetail detail;
   detail.mapLayerId = QStringLiteral( "layer3" );
   detail.name = QStringLiteral( "xxx" );
@@ -235,12 +233,12 @@ void TestQgsGeospatialPdfExport::testComposition()
   QDomNodeList ifLayerOnList = doc.elementsByTagName( QStringLiteral( "IfLayerOn" ) );
   QCOMPARE( ifLayerOnList.count(), 3 );
 
-  int layer1Idx = ifLayerOnList.at( 0 ).toElement().attribute( QStringLiteral( "layerId" ) ) == QLatin1String( "layer1" ) ? 0 :
-                  ifLayerOnList.at( 1 ).toElement().attribute( QStringLiteral( "layerId" ) ) == QLatin1String( "layer1" ) ? 1 : 2;
-  int layer2Idx = ifLayerOnList.at( 0 ).toElement().attribute( QStringLiteral( "layerId" ) ) == QLatin1String( "layer2" ) ? 0 :
-                  ifLayerOnList.at( 1 ).toElement().attribute( QStringLiteral( "layerId" ) ) == QLatin1String( "layer2" ) ? 1 : 2;
-  int layer3Idx = ifLayerOnList.at( 0 ).toElement().attribute( QStringLiteral( "layerId" ) ) == QLatin1String( "layer3" ) ? 0 :
-                  ifLayerOnList.at( 1 ).toElement().attribute( QStringLiteral( "layerId" ) ) == QLatin1String( "layer3" ) ? 1 : 2;
+  int layer1Idx = ifLayerOnList.at( 0 ).toElement().attribute( QStringLiteral( "layerId" ) ) == QLatin1String( "layer1" ) ? 0 : ifLayerOnList.at( 1 ).toElement().attribute( QStringLiteral( "layerId" ) ) == QLatin1String( "layer1" ) ? 1
+                                                                                                                                                                                                                                        : 2;
+  int layer2Idx = ifLayerOnList.at( 0 ).toElement().attribute( QStringLiteral( "layerId" ) ) == QLatin1String( "layer2" ) ? 0 : ifLayerOnList.at( 1 ).toElement().attribute( QStringLiteral( "layerId" ) ) == QLatin1String( "layer2" ) ? 1
+                                                                                                                                                                                                                                        : 2;
+  int layer3Idx = ifLayerOnList.at( 0 ).toElement().attribute( QStringLiteral( "layerId" ) ) == QLatin1String( "layer3" ) ? 0 : ifLayerOnList.at( 1 ).toElement().attribute( QStringLiteral( "layerId" ) ) == QLatin1String( "layer3" ) ? 1
+                                                                                                                                                                                                                                        : 2;
   QCOMPARE( ifLayerOnList.at( layer1Idx ).toElement().attribute( QStringLiteral( "layerId" ) ), QStringLiteral( "layer1" ) );
   QCOMPARE( ifLayerOnList.at( layer1Idx ).toElement().elementsByTagName( QStringLiteral( "Vector" ) ).at( 0 ).toElement().attribute( QStringLiteral( "dataset" ) ), layer1Path );
   QCOMPARE( ifLayerOnList.at( layer1Idx ).toElement().elementsByTagName( QStringLiteral( "Vector" ) ).at( 0 ).toElement().attribute( QStringLiteral( "layer" ) ), layer1Layer );
@@ -259,7 +257,6 @@ void TestQgsGeospatialPdfExport::testComposition()
   QCOMPARE( ifLayerOnList.at( layer3Idx ).toElement().elementsByTagName( QStringLiteral( "PDF" ) ).at( 0 ).toElement().attribute( QStringLiteral( "dataset" ) ), QStringLiteral( "a pdf.pdf" ) );
   QCOMPARE( ifLayerOnList.at( layer3Idx ).toElement().elementsByTagName( QStringLiteral( "PDF" ) ).at( 0 ).toElement().elementsByTagName( QStringLiteral( "Blending" ) ).at( 0 ).toElement().attribute( QStringLiteral( "opacity" ) ).toDouble(), 0.7 );
   QCOMPARE( ifLayerOnList.at( layer3Idx ).toElement().elementsByTagName( QStringLiteral( "PDF" ) ).at( 0 ).toElement().elementsByTagName( QStringLiteral( "Blending" ) ).at( 0 ).toElement().attribute( QStringLiteral( "function" ) ), QStringLiteral( "Screen" ) );
-
 }
 
 void TestQgsGeospatialPdfExport::testMetadata()
@@ -267,7 +264,7 @@ void TestQgsGeospatialPdfExport::testMetadata()
   TestGeospatialPdfExporter geospatialPdfExporter;
   // test creation of the composition xml with metadata
 
-  QList< QgsAbstractGeospatialPdfExporter::ComponentLayerDetail > renderedLayers;
+  QList<QgsAbstractGeospatialPdfExporter::ComponentLayerDetail> renderedLayers;
   QgsAbstractGeospatialPdfExporter::ExportDetails details;
   QString composition = geospatialPdfExporter.createCompositionXml( renderedLayers, details );
   QgsDebugMsgLevel( composition, 1 );
@@ -300,7 +297,6 @@ void TestQgsGeospatialPdfExport::testMetadata()
   QCOMPARE( doc.elementsByTagName( QStringLiteral( "Subject" ) ).at( 0 ).toElement().text(), QStringLiteral( "my subject" ) );
   QCOMPARE( doc.elementsByTagName( QStringLiteral( "Title" ) ).at( 0 ).toElement().text(), QStringLiteral( "my title" ) );
   QCOMPARE( doc.elementsByTagName( QStringLiteral( "Keywords" ) ).at( 0 ).toElement().text(), QStringLiteral( "k1: v1,v2" ) );
-
 }
 
 void TestQgsGeospatialPdfExport::testGeoref()
@@ -308,7 +304,7 @@ void TestQgsGeospatialPdfExport::testGeoref()
   TestGeospatialPdfExporter geospatialPdfExporter;
   // test creation of the composition xml with georeferencing
 
-  QList< QgsAbstractGeospatialPdfExporter::ComponentLayerDetail > renderedLayers;
+  QList<QgsAbstractGeospatialPdfExporter::ComponentLayerDetail> renderedLayers;
   QgsAbstractGeospatialPdfExporter::ExportDetails details;
   QString composition = geospatialPdfExporter.createCompositionXml( renderedLayers, details );
   QgsDebugMsgLevel( composition, 1 );
@@ -358,7 +354,7 @@ void TestQgsGeospatialPdfExport::testGeorefPolygon()
   // test georeferencing a region using polygon bounds
   TestGeospatialPdfExporter geospatialPdfExporter;
 
-  QList< QgsAbstractGeospatialPdfExporter::ComponentLayerDetail > renderedLayers;
+  QList<QgsAbstractGeospatialPdfExporter::ComponentLayerDetail> renderedLayers;
   QgsAbstractGeospatialPdfExporter::ExportDetails details;
 
   // with points
@@ -442,7 +438,7 @@ void TestQgsGeospatialPdfExport::testGroups()
   }
 
   // test creation of the composition xml
-  QList< QgsAbstractGeospatialPdfExporter::ComponentLayerDetail > renderedLayers; // no extra layers for now
+  QList<QgsAbstractGeospatialPdfExporter::ComponentLayerDetail> renderedLayers; // no extra layers for now
   QgsAbstractGeospatialPdfExporter::ExportDetails details;
   QString composition = geospatialPdfExporter.createCompositionXml( renderedLayers, details );
   QgsDebugMsgLevel( composition, 1 );
@@ -480,7 +476,6 @@ void TestQgsGeospatialPdfExport::testGroups()
   QCOMPARE( layerTreeList.at( layer2Idx ).toElement().attribute( QStringLiteral( "id" ) ), QStringLiteral( "layer2" ) );
   QCOMPARE( layerTreeList.at( layer2Idx ).toElement().attribute( QStringLiteral( "name" ) ), QStringLiteral( "name layer2" ) );
   QCOMPARE( layerTreeList.at( layer2Idx ).toElement().attribute( QStringLiteral( "initiallyVisible" ) ), QStringLiteral( "true" ) );
-
 }
 
 void TestQgsGeospatialPdfExport::testCustomGroups()
@@ -523,7 +518,7 @@ void TestQgsGeospatialPdfExport::testCustomGroups()
   }
 
   // test creation of the composition xml
-  QList< QgsAbstractGeospatialPdfExporter::ComponentLayerDetail > renderedLayers; // no extra layers for now
+  QList<QgsAbstractGeospatialPdfExporter::ComponentLayerDetail> renderedLayers; // no extra layers for now
   QgsAbstractGeospatialPdfExporter::ExportDetails details;
   details.customLayerTreeGroups.insert( QStringLiteral( "layer1" ), QStringLiteral( "my group" ) );
   details.customLayerTreeGroups.insert( QStringLiteral( "layer2" ), QStringLiteral( "my group2" ) );
@@ -618,12 +613,12 @@ void TestQgsGeospatialPdfExport::testGroupOrder()
   }
 
   // test creation of the composition xml
-  QList< QgsAbstractGeospatialPdfExporter::ComponentLayerDetail > renderedLayers; // no extra layers for now
+  QList<QgsAbstractGeospatialPdfExporter::ComponentLayerDetail> renderedLayers; // no extra layers for now
   QgsAbstractGeospatialPdfExporter::ExportDetails details;
   details.customLayerTreeGroups.insert( QStringLiteral( "layer1" ), QStringLiteral( "my group" ) );
   details.customLayerTreeGroups.insert( QStringLiteral( "layer2" ), QStringLiteral( "my group2" ) );
 
-  details.layerTreeGroupOrder = QStringList{ QStringLiteral( "my group2" ), QStringLiteral( "my group" )};
+  details.layerTreeGroupOrder = QStringList { QStringLiteral( "my group2" ), QStringLiteral( "my group" ) };
 
   QString composition = geospatialPdfExporter.createCompositionXml( renderedLayers, details );
   QgsDebugMsgLevel( composition, 1 );
@@ -635,7 +630,7 @@ void TestQgsGeospatialPdfExport::testGroupOrder()
   QCOMPARE( layerTreeList.at( 0 ).toElement().attribute( QStringLiteral( "name" ) ), QStringLiteral( "my group2" ) );
   QCOMPARE( layerTreeList.at( 1 ).toElement().attribute( QStringLiteral( "name" ) ), QStringLiteral( "my group" ) );
 
-  details.layerTreeGroupOrder = QStringList{ QStringLiteral( "my group" ), QStringLiteral( "my group2" )};
+  details.layerTreeGroupOrder = QStringList { QStringLiteral( "my group" ), QStringLiteral( "my group2" ) };
 
   composition = geospatialPdfExporter.createCompositionXml( renderedLayers, details );
   QgsDebugMsgLevel( composition, 1 );
@@ -647,7 +642,7 @@ void TestQgsGeospatialPdfExport::testGroupOrder()
   QCOMPARE( layerTreeList.at( 1 ).toElement().attribute( QStringLiteral( "name" ) ), QStringLiteral( "my group2" ) );
 
   // incomplete list
-  details.layerTreeGroupOrder = QStringList{ QStringLiteral( "my group2" )};
+  details.layerTreeGroupOrder = QStringList { QStringLiteral( "my group2" ) };
 
   composition = geospatialPdfExporter.createCompositionXml( renderedLayers, details );
   QgsDebugMsgLevel( composition, 1 );
@@ -659,7 +654,7 @@ void TestQgsGeospatialPdfExport::testGroupOrder()
   QCOMPARE( layerTreeList.at( 1 ).toElement().attribute( QStringLiteral( "name" ) ), QStringLiteral( "my group" ) );
 
   // list with extra groups which don't have content
-  details.layerTreeGroupOrder = QStringList{ QStringLiteral( "aaa" ), QStringLiteral( "my group" )};
+  details.layerTreeGroupOrder = QStringList { QStringLiteral( "aaa" ), QStringLiteral( "my group" ) };
 
   composition = geospatialPdfExporter.createCompositionXml( renderedLayers, details );
   QgsDebugMsgLevel( composition, 1 );
@@ -722,7 +717,7 @@ void TestQgsGeospatialPdfExport::testMutuallyExclusiveGroupsLayers()
   }
 
   // test creation of the composition xml
-  QList< QgsAbstractGeospatialPdfExporter::ComponentLayerDetail > renderedLayers; // no extra layers for now
+  QList<QgsAbstractGeospatialPdfExporter::ComponentLayerDetail> renderedLayers; // no extra layers for now
   QgsAbstractGeospatialPdfExporter::ExportDetails details;
   details.customLayerTreeGroups.insert( QStringLiteral( "layer1" ), QStringLiteral( "my group" ) );
   details.customLayerTreeGroups.insert( QStringLiteral( "layer2" ), QStringLiteral( "my group2" ) );
@@ -769,12 +764,15 @@ void TestQgsGeospatialPdfExport::testMutuallyExclusiveGroupsLayers()
   QDomNodeList contentList = doc.documentElement().firstChildElement( QStringLiteral( "Page" ) ).firstChildElement( QStringLiteral( "Content" ) ).childNodes();
   QCOMPARE( contentList.count(), 3 );
 
-  int layer1Idx = contentList.at( 0 ).toElement().attribute( QStringLiteral( "layerId" ) ) == group1Id ? 0
-                  : contentList.at( 1 ).toElement().attribute( QStringLiteral( "layerId" ) ) == group1Id ? 1 : 2;
-  int layer2Idx = contentList.at( 0 ).toElement().attribute( QStringLiteral( "layerId" ) ) == group2Id ? 0
-                  : contentList.at( 1 ).toElement().attribute( QStringLiteral( "layerId" ) ) == group2Id ? 1 : 2;
-  int layer3Idx = contentList.at( 0 ).toElement().attribute( QStringLiteral( "layerId" ) ) == group3Id ? 0
-                  : contentList.at( 1 ).toElement().attribute( QStringLiteral( "layerId" ) ) == group3Id ? 1 : 2;
+  int layer1Idx = contentList.at( 0 ).toElement().attribute( QStringLiteral( "layerId" ) ) == group1Id   ? 0
+                  : contentList.at( 1 ).toElement().attribute( QStringLiteral( "layerId" ) ) == group1Id ? 1
+                                                                                                         : 2;
+  int layer2Idx = contentList.at( 0 ).toElement().attribute( QStringLiteral( "layerId" ) ) == group2Id   ? 0
+                  : contentList.at( 1 ).toElement().attribute( QStringLiteral( "layerId" ) ) == group2Id ? 1
+                                                                                                         : 2;
+  int layer3Idx = contentList.at( 0 ).toElement().attribute( QStringLiteral( "layerId" ) ) == group3Id   ? 0
+                  : contentList.at( 1 ).toElement().attribute( QStringLiteral( "layerId" ) ) == group3Id ? 1
+                                                                                                         : 2;
   QCOMPARE( contentList.at( layer1Idx ).toElement().attribute( QStringLiteral( "layerId" ) ), group1Id );
   QCOMPARE( contentList.at( layer1Idx ).toElement().firstChildElement().tagName(), QStringLiteral( "IfLayerOn" ) );
   QCOMPARE( contentList.at( layer1Idx ).toElement().firstChildElement().attribute( QStringLiteral( "layerId" ) ), QStringLiteral( "my group_layer1" ) );
@@ -810,15 +808,15 @@ void TestQgsGeospatialPdfExport::testMutuallyExclusiveGroupsCustom()
   // test creation of the composition xml
   QgsAbstractGeospatialPdfExporter::ComponentLayerDetail group1;
   group1.group = QStringLiteral( "my group" );
-  group1.sourcePdfPath =  QStringLiteral( "group1.pdf" );
+  group1.sourcePdfPath = QStringLiteral( "group1.pdf" );
   QgsAbstractGeospatialPdfExporter::ComponentLayerDetail group2;
   group2.group = QStringLiteral( "my group2" );
-  group2.sourcePdfPath =  QStringLiteral( "group2.pdf" );
+  group2.sourcePdfPath = QStringLiteral( "group2.pdf" );
   QgsAbstractGeospatialPdfExporter::ComponentLayerDetail group3;
   group3.group = QStringLiteral( "my group3" );
-  group3.sourcePdfPath =  QStringLiteral( "group3.pdf" );
+  group3.sourcePdfPath = QStringLiteral( "group3.pdf" );
   QgsAbstractGeospatialPdfExporter::ComponentLayerDetail object4;
-  object4.sourcePdfPath =  QStringLiteral( "object4.pdf" );
+  object4.sourcePdfPath = QStringLiteral( "object4.pdf" );
 
   QgsAbstractGeospatialPdfExporter::ExportDetails details;
   // groups 1 & 2 should be mutually exclusive
